@@ -3,7 +3,7 @@
 // Purpose:     Manage cache of transcoded files
 // Author:      Alex Thuering
 // Created:     29.08.2008
-// RCS-ID:      $Id: Cache.h,v 1.4 2011/05/15 19:08:43 ntalex Exp $
+// RCS-ID:      $Id: Cache.h,v 1.6 2014/09/20 06:04:42 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -12,8 +12,9 @@
 #define DVDSTYLER_CACHE_H
 
 #include "DVD.h"
-#include "mediatrc.h"
+#include "mediaenc.h"
 #include <wx/hashmap.h>
+#include <wx/window.h>
 
 class CacheEntry;
 WX_DECLARE_STRING_HASH_MAP(CacheEntry*, CacheMap);
@@ -53,6 +54,11 @@ public:
 	 */
 	int GetCount();
 	
+	/**
+	 * Return size of files in cache (in KB)
+	 */
+	long GetSize();
+	
 	/**
 	 * Checks if there is a file for given VOB in the cache
 	 * @return The file name in cache or empty string if no match entry in cache
@@ -65,6 +71,11 @@ public:
 	 */
 	wxString Add(Vob* vob, DVD* dvd);
 	
+	/**
+	 * Removes an entry for given VOB from the cache
+	 */
+	void Remove(Vob* vob);
+	
 	/**
 	 * Removes all files from cache
 	 */
@@ -79,6 +90,17 @@ public:
 	 * Removes all unused entries
 	 */
 	void EndClean();
+	
+	/**
+	 * Saves list of cache entries
+	 */
+	void Save();
+	
+	/**
+	 * Shows prompt dialog and clears or saves cache 
+	 */
+	void ShowClearPrompt(wxWindow* parent);
+
 private:
 	wxString m_dir;
 	CacheMap m_cacheMap;
@@ -97,11 +119,6 @@ private:
 	 * Loads list of cache entries
 	 */
 	bool Open();
-	
-	/**
-	 * Saves list of cache entries
-	 */
-	void Save();
 };
 
 #endif //DVDSTYLER_CACHE_H
