@@ -3,7 +3,7 @@
 // Purpose:     Configuration
 // Author:      Alex Thuering
 // Created:     27.03.2003
-// RCS-ID:      $Id: Config.h,v 1.86 2013/06/16 19:27:48 ntalex Exp $
+// RCS-ID:      $Id: Config.h,v 1.99 2015/02/15 14:33:34 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -15,6 +15,7 @@
 #include <wx/config.h>
 #include <wx/thread.h>
 #include <wx/filename.h>
+#include "Utils.h"
 
 const wxString DEF_VERSION		= wxT("");
 const int DEF_LANGUAGE			= wxLANGUAGE_UNKNOWN;
@@ -27,32 +28,36 @@ const int DEF_AUDIO_FORMAT		= 3;
 const wxString DEF_AUDIO_LANG	= wxT("");
 const wxString DEF_SUBTITLE_LANG= wxT("");
 const int DEF_ASPECT_RATIO		= 1;
-const bool DEF_KEEP_ASPECT_RATIO= true;
 const int DEF_CHAPTER_LENGTH	= 10;
 const wxString DEF_BUTTON		= wxT("frame-v2.xml");
 const wxString DEF_TEXT_BUTTON	= wxT("text-v3.xml");
-const bool DEF_ACCEPT_INVALID_ACTIONS = false;
+const int DEF_SLIDE_DURATION = 5;
+const wxString DEF_TRANSITION = wxT("fade.xml");
+const double DEF_TRANSITION_DURATION = 1.0;
 const wxString DEF_FILE_BROWSER_DIR = wxT("");
 #define DEF_FILE_BROWSER_LAST_DIR wxGetHomeDir()
 #define DEF_LAST_PROJECT_DIR wxGetHomeDir()
 #define DEF_LAST_ADD_DIR wxGetHomeDir()
 const int DEF_UNDO_HISTORY_SIZE = 100;
-const bool DEF_REMOVE_TEMP = true;
-const bool DEF_VBR = false;
 const int DEF_VIDEO_BITRATE = -1;
 const int DEF_AUDIO_BITRATE = 192;
 const int DEF_MENU_FRAME_COUNT = 12;
 const int DEF_MENU_VIDEO_BITRATE = 6000;
-const bool DEF_DRAW_BUTTONS_ON_BACKGROUND = true;
 const int DEF_SLIDESHOW_VIDEO_BITRATE = 6000;
 const int DEF_THREAD_COUNT = wxThread::GetCPUCount() > 0 ? wxThread::GetCPUCount() : 1;
 const int DEF_DVD_RESERVED_SPACE = 0; // KB
 #define DEF_GEN_TEMP_DIR wxFileName::GetTempDir()
+#define DEF_GEN_OUTPUT_DIR wxGetHomeDir()
 #ifdef __WXMSW__
 	const bool DEF_PREVIEW_DO        = false;
 	const wxString DEF_PREVIEW_CMD   = _T("wmplayer");
 	const wxString DEF_BURN_DEVICE   = _T("");
 	const wxString DEF_ADD_ECC_CMD   = _T("\"C:\\Program Files\\dvdisaster\\dvdisaster\" -mRS02 -n dvd -c -i \"$FILE\"");
+#elif defined(__WXMAC__)
+	const bool DEF_PREVIEW_DO        = true;
+	const wxString DEF_PREVIEW_CMD   = _T("/Applications/VLC.app/Contents/MacOS/VLC");
+	const wxString DEF_BURN_DEVICE   = _T("/dev/dvd");
+	const wxString DEF_ADD_ECC_CMD   = _T("dvdisaster -mRS02 -n dvd -c -i \"$FILE\"");
 #else
 	const bool DEF_PREVIEW_DO        = true;
 	const wxString DEF_PREVIEW_CMD   = _T("xine \"dvd:/$DIR\"");
@@ -98,12 +103,29 @@ const bool DEF_ADD_ECC_DO        = false;
 #define CONFIG_PROP_INT(name, cfgName, defValue)\
   CONFIG_PROP_T(name, cfgName, defValue, int, long)
 
+//#define CONFIG_PROP_DOUBLE(name, cfgName, defValue)
+//  CONFIG_PROP_T(name, cfgName, defValue, double, double)
+
 #define CONFIG_PROP_T(name, cfgName, defValue, cfgType, cfgType2)\
   cfgType Get##name(bool def = false)\
   { return def ? (cfgType2) defValue : cfg->Read(cfgName, (cfgType2) defValue); }\
   void Set##name(cfgType value)\
   { wxLogNull log; if (value == defValue) cfg->DeleteEntry(cfgName); else cfg->Write(cfgName, value); }
 
+#define CONFIG_PROP_DOUBLE(name, cfgName, defValue)\
+  double Get##name(bool def = false)\
+  { if (def) return defValue; wxString val = cfg->Read(cfgName, wxString::Format(wxT("%f"), defValue));\
+  	  double dval; if (val.ToDouble(&dval)) return dval; return defValue; }\
+  void Set##name(double value)\
+  { wxLogNull log; if (value == defValue) cfg->DeleteEntry(cfgName); \
+	else cfg->Write(cfgName, wxString::Format(wxT("%f"), value)); }
+
+#define CONFIG_PROP_COLOUR(name, cfgName, defValue)\
+  wxColour Get##name(bool def = false)\
+  { if (def) return defValue; wxString val = cfg->Read(cfgName, Colour2String(defValue)); return String2Colour(val); }\
+  void Set##name(const wxColour& value)\
+  { wxLogNull log; if (value == defValue) cfg->DeleteEntry(cfgName); else cfg->Write(cfgName, Colour2String(value)); }
+
 class Config {
 public:
     void Init();
@@ -128,28 +150,58 @@ public:
 	CONFIG_PROP(DefAudioLanguage, _T("Interface/DefAudioLanguage"), DEF_AUDIO_LANG)
 	CONFIG_PROP(DefSubtitleLanguage, _T("Interface/DefSubtitleLanguage"), DEF_SUBTITLE_LANG)
 	CONFIG_PROP_INT(DefAspectRatio, _T("Interface/DefAspectRatio"), DEF_ASPECT_RATIO)
-	CONFIG_PROP_BOOL(DefKeepAspectRatio, _T("Interface/DefKeepAspectRatio"), DEF_KEEP_ASPECT_RATIO)
+	CONFIG_PROP_BOOL(DefKeepAspectRatio, _T("Interface/DefKeepAspectRatio"), true)
+	CONFIG_PROP_BOOL(DefRencodeNtscFilm, _T("Interface/DefRencodeNtscFilm"), true)
+	CONFIG_PROP_BOOL(DefAudio51, _T("Interface/DefAudio51"), false)
+	CONFIG_PROP_BOOL(DefAudioNormalize, _T("Interface/DefAudioNormalize"), false)
 	CONFIG_PROP_INT(DefChapterLength, _T("Interface/DefChapterLength"), DEF_CHAPTER_LENGTH)
 	CONFIG_PROP(DefButton, _T("Interface/DefButton"), DEF_BUTTON)
 	CONFIG_PROP(DefTextButton, _T("Interface/DefTextButton"), DEF_TEXT_BUTTON)
-	CONFIG_PROP_BOOL(AcceptInvalidActions, _T("Interface/AcceptInvalidActions"), DEF_ACCEPT_INVALID_ACTIONS)
+	CONFIG_PROP_BOOL(DefPlayAllTitlesets, _T("Interface/DefPlayAllTitlesets"), false)
+	CONFIG_PROP_INT(DefSlideDuration, _T("Interface/DefSlideDuration"), DEF_SLIDE_DURATION)
+	CONFIG_PROP(DefTransition, _T("Interface/DefTransition"), DEF_TRANSITION)
+	CONFIG_PROP_DOUBLE(DefTransitionDuration, _T("Interface/DefTransitionDuration"), DEF_TRANSITION_DURATION)
+	CONFIG_PROP_BOOL(AcceptInvalidActions, _T("Interface/AcceptInvalidActions"), false)
 	CONFIG_PROP(FileBrowserDir, _T("Interface/FileBrowserDir"), DEF_FILE_BROWSER_DIR)
 	CONFIG_PROP(FileBrowserLastDir, _T("Interface/FileBrowserLastDir"), DEF_FILE_BROWSER_LAST_DIR)
 	CONFIG_PROP(LastProjectDir, _T("Interface/LastProjectDir"), DEF_LAST_PROJECT_DIR)
 	CONFIG_PROP(LastAddDir, _T("Interface/LastAddDir"), DEF_LAST_ADD_DIR)
 	CONFIG_PROP_INT(UndoHistorySize, _T("Interface/UndoHistorySize"), DEF_UNDO_HISTORY_SIZE)
 	CONFIG_PROP_BOOL(ShowWelcomeDlg, _T("Interface/ShowWelcomeDlg"), true)
-	CONFIG_PROP_BOOL(ShowTitleDeletePrompt, _T("Interface/ShowTitleDeletePrompt"), true)
+	CONFIG_PROP_BOOL(TitleDeletePrompt, _T("Interface/TitleDeletePrompt"), true)
+	CONFIG_PROP_INT(CacheClearPrompt, _T("Interface/CacheClearPrompt"), 0)
+	CONFIG_PROP_BOOL(OverwriteOutputDirPrompt, _T("Interface/OverwriteOutputDirPrompt"), true)
 	CONFIG_PROP_BOOL(ClearThumbnailCache, _T("Interface/ClearThumbnailCache"), false)
 	
+	CONFIG_PROP(SubtitlesCharacterSet, _T("Subtitles/CharacterSet"), wxT("UTF-8"))
+	CONFIG_PROP(SubtitlesFontFamily, _T("Subtitles/FontFamily"), wxT("Arial"))
+	CONFIG_PROP(SubtitlesFontStyle, _T("Subtitles/FontStyle"), wxT("Regular"))
+	CONFIG_PROP_DOUBLE(SubtitlesFontSize, _T("Subtitles/FontSize"), 28.0)
+#if !wxCHECK_VERSION(2,9,0)
+	CONFIG_PROP_COLOUR(SubtitlesFillColour, _T("Subtitles/FillColour"), wxColour(255, 255, 0))
+#else
+	CONFIG_PROP_COLOUR(SubtitlesFillColour, _T("Subtitles/FillColour"), *wxYELLOW)
+#endif
+	CONFIG_PROP_COLOUR(SubtitlesOutlineColour, _T("Subtitles/OutlineColour"), *wxBLACK)
+	CONFIG_PROP_DOUBLE(SubtitlesOutlineThickness, _T("Subtitles/OutlineThickness"), 3.0)
+	CONFIG_PROP_COLOUR(SubtitlesShadowColour, _T("Subtitles/ShadowColour"), *wxBLACK)
+	CONFIG_PROP_INT(SubtitlesShadowOffsetX, _T("Subtitles/ShadowOffsetX"), 0)
+	CONFIG_PROP_INT(SubtitlesShadowOffsetY, _T("Subtitles/ShadowOffsetY"), 0)
+	CONFIG_PROP_INT(SubtitlesAlignment, _T("Subtitles/Alignment"), (wxALIGN_CENTER_HORIZONTAL | wxALIGN_BOTTOM))
+	CONFIG_PROP_INT(SubtitlesLeftMargin, _T("Subtitles/LeftMargin"), 60)
+	CONFIG_PROP_INT(SubtitlesRightMargin, _T("Subtitles/RightMargin"), 60)
+	CONFIG_PROP_INT(SubtitlesTopMargin, _T("Subtitles/TopMargin"), 20)
+	CONFIG_PROP_INT(SubtitlesBottomMargin, _T("Subtitles/BottomMargin"), 30)
+	
 	CONFIG_PROP(TempDir, _T("Generate/TempDir"), DEF_GEN_TEMP_DIR)
-	CONFIG_PROP_BOOL(RemoveTempFiles, _T("Generate/RemoveTempFiles"), DEF_REMOVE_TEMP)
-	CONFIG_PROP_INT(Vbr, _T("Generate/Vbr"), DEF_VBR)
+	CONFIG_PROP(OutputDir, _T("Generate/OutputDir"), DEF_GEN_OUTPUT_DIR)
+	CONFIG_PROP_BOOL(RemoveTempFiles, _T("Generate/RemoveTempFiles"), true)
+	CONFIG_PROP_INT(Vbr, _T("Generate/Vbr"), false)
 	CONFIG_PROP_INT(VideoBitrate, _T("Generate/VideoBitrate"), DEF_VIDEO_BITRATE)
 	CONFIG_PROP_INT(AudioBitrate, _T("Generate/AudioBitrate"), DEF_AUDIO_BITRATE)
 	CONFIG_PROP_INT(MenuFrameCount,_T("Generate/MenuFrameCount"), DEF_MENU_FRAME_COUNT)
 	CONFIG_PROP_INT(MenuVideoBitrate, _T("Generate/MenuVideoBitrate"), DEF_MENU_VIDEO_BITRATE)
-	CONFIG_PROP_BOOL(DrawButtonsOnBackground, _T("Generate/DrawButtonsOnBackground"), DEF_DRAW_BUTTONS_ON_BACKGROUND)
+	CONFIG_PROP_BOOL(DrawButtonsOnBackground, _T("Generate/DrawButtonsOnBackground"), true)
     CONFIG_PROP_INT(SlideshowVideoBitrate, _T("Generate/SlideshowVideoBitrate"), DEF_SLIDESHOW_VIDEO_BITRATE)
     CONFIG_PROP_INT(ThreadCount, _T("Generate/ThreadCount"), DEF_THREAD_COUNT)
     CONFIG_PROP_INT(DvdReservedSpace, _T("Generate/DvdReservedSpace"), DEF_DVD_RESERVED_SPACE)
