@@ -3,7 +3,7 @@
 // Purpose:     Main window
 // Author:      Alex Thuering
 // Created:     10.10.2003
-// RCS-ID:      $Id: MainWin.cpp,v 1.185 2014/03/10 12:20:44 ntalex Exp $
+// RCS-ID:      $Id: MainWin.cpp,v 1.189 2014/09/27 06:01:55 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -18,6 +18,7 @@
 #include "SettingsDlg.h"
 #include "Config.h"
 #include "MPEG.h"
+#include "MessageDlg.h"
 #include <wxVillaLib/VerticalToolbar.h>
 #include <wxVillaLib/SingleThumbnailDlg.h>
 #include <wxVillaLib/utils.h>
@@ -50,7 +51,7 @@
 #include "rc/preferences.png.h"
 #include "rc/run.png.h"
 #include "rc/files.png.h"
-#include "rc/add.png.h"
+#include "rc/addVideo.png.h"
 
 #define BACKGROUNDS_DIR wxFindDataDirectory(_T("backgrounds"))
 #define BUTTONS_DIR wxFindDataDirectory(_T("buttons"))
@@ -271,7 +272,6 @@ MainWin::MainWin(): wxFrame(NULL, -1, _T(""), wxDefaultPosition, wxDefaultSize,
 }
 
 MainWin::~MainWin() {
-	m_cache.Clear();
 #ifdef __WXMSW__
 	if (m_taskbarInterface != NULL)
 		m_taskbarInterface->Release();
@@ -306,7 +306,7 @@ void MainWin::set_properties() {
 			_("Burn..."), wxT(""));
 	m_toolbar->AddSeparator();
 #if wxCHECK_VERSION(2,9,0)
-	m_toolbar->AddTool(MENU_DVD_ADD_FILE_ID,  wxT(""), wxBITMAP_FROM_MEMORY(add), wxNullBitmap, wxITEM_DROPDOWN,
+	m_toolbar->AddTool(MENU_DVD_ADD_FILE_ID,  wxT(""), wxBITMAP_FROM_MEMORY(addVideo), wxNullBitmap, wxITEM_DROPDOWN,
 			_("Add File..."), wxT(""));
 	wxMenu* addMenu = new wxMenu;
 	addMenu->Append(MENU_DVD_ADD_FILE_ID, _("&File..."));
@@ -314,7 +314,7 @@ void MainWin::set_properties() {
 	addMenu->Append(MENU_DVD_ADD_TITLES_FROM_DVD_ID, _("Titles from &DVD..."));
 	m_toolbar->SetDropdownMenu(MENU_DVD_ADD_FILE_ID, addMenu);
 #else
-	m_toolbar->AddTool(MENU_DVD_ADD_FILE_ID,  wxT(""), wxBITMAP_FROM_MEMORY(add), wxNullBitmap, wxITEM_NORMAL,
+	m_toolbar->AddTool(MENU_DVD_ADD_FILE_ID,  wxT(""), wxBITMAP_FROM_MEMORY(addVideo), wxNullBitmap, wxITEM_NORMAL,
 			_("Add File..."), wxT(""));
 #endif
 	m_toolbar->Realize();
@@ -664,6 +664,7 @@ void MainWin::OnClose(wxCloseEvent &event) {
 		event.Veto();
 		return;
 	}
+	m_cache.ShowClearPrompt(this);
 	if (!IsIconized())
 		s_config.SetMainWinLocation(GetRect(), IsMaximized());
 	Destroy();
@@ -790,7 +791,9 @@ void MainWin::NewDVD(wxString templateFile, wxString discTitle, wxString discLab
 	}
 	UpdateDVD();
 	SetChanged(false);
-	m_cache.Clear();
+	if (s_config.GetCacheClearPrompt() == 1) {
+		m_cache.Clear();
+	}
 }
 
 bool MainWin::Open(wxString filename) {
@@ -817,7 +820,9 @@ bool MainWin::Open(wxString filename) {
 	s_config.SetLastProjectDir(m_lastDir);
 	UpdateDVD();
 	SetChanged(false);
-	m_cache.Clear();
+	if (s_config.GetCacheClearPrompt() == 1) {
+		m_cache.Clear();
+	}
 	m_fileHistory.AddFileToHistory(m_dvd->GetFilename());
 	m_fileHistory.Save(*s_config.GetConfigBase());
 
@@ -899,10 +904,29 @@ void MainWin::OnChangedDVD(wxCommandEvent& event) {
 
 void MainWin::DoChangedDVD(bool doUndo) {
 	SetChanged(true, doUndo);
-	wxArrayInt b = m_dvd->CalculateVideoBitrate();
-	long size = m_dvd->GetSize();
-	long total = m_dvd->GetCapacityValue();
-	m_statusbar->SetFillStatus(size, total, b[1], b[2]/60, b[0], m_dvd->IsVideoBitrateAuto(), m_dvd->GetAudioBitrate());
+	long encSize, encDuration, fixSize, fixDuration, fixAvgBitrate;
+	m_dvd->CalculateVideoBitrate(encSize, encDuration, fixSize, fixDuration, fixAvgBitrate);
+	long sizeTotal = m_dvd->GetCapacityValue();
+	int videoBitrate = m_dvd->GetVideoBitrate();
+	int audioBitrate = m_dvd->GetAudioBitrate();
+	
+	int bitrateForTotal = videoBitrate + audioBitrate;
+	if (m_dvd->IsVideoBitrateAuto()) {
+		if (encDuration == 0 && fixDuration > 0) {
+			bitrateForTotal = fixAvgBitrate;
+		}
+		if (bitrateForTotal > 4500)
+			bitrateForTotal = 4500;
+	}
+	
+	int dur = fixDuration/60 + encDuration/60;
+	int durTotal = sizeTotal > 0 ? fixDuration/60 + (sizeTotal-fixSize)*8/bitrateForTotal/60 : 0;
+	
+	// If video bitrate doesn't set to auto, display selected bitrate. 
+	// Else if video must be encoded, display calculated bitrate that will be used for encoding.
+	// Else if video will be copied without encoding, display average bitrate of all video files.
+	// Else if no titles exits, display 8 MB/s
+	m_statusbar->SetFillStatus(dur, durTotal, encDuration == 0 && fixDuration > 0 ? fixAvgBitrate : videoBitrate);
 	m_menuEditor->ShowSafeTV();
 	m_menuEditor->Refresh();
 }
