@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD Menu
 // Author:      Alex Thuering
 // Created:	04.11.2003
-// RCS-ID:      $Id: Menu.cpp,v 1.120 2014/02/03 14:27:47 ntalex Exp $
+// RCS-ID:      $Id: Menu.cpp,v 1.123 2014/04/29 20:06:34 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -703,7 +703,7 @@ wxString Menu::AddObject(wxString fileName, wxString param, int x, int y) {
 
 /** Returns button with given jump action */
 MenuObject* Menu::GetButtonByJumpAction(int actionTsi, int actionPgci, bool actionIsMenu) {
-	for (unsigned int obji = 0; obji < m_objects.GetCount(); obji++) {
+	for (unsigned int obji = 0; obji < m_objects.size(); obji++) {
 		MenuObject* obj = m_objects[obji];
 		if (obj->IsButton() && !obj->GetAction().IsCustom() && obj->GetAction().GetTsi() == actionTsi
 				&& obj->GetAction().GetPgci() == actionPgci && obj->GetAction().IsMenu() == actionIsMenu) {
@@ -715,37 +715,57 @@ MenuObject* Menu::GetButtonByJumpAction(int actionTsi, int actionPgci, bool acti
 
 /** Updates image in buttons with given jump action */
 bool Menu::UpdateButtonImageFor(int actionTsi, int actionPgci, DVD* dvd) {
+	Pgc* pgc = dvd->GetPgc(actionTsi == -2 ? m_tsi : actionTsi, false, actionPgci);
+	int vobId = DVD::MakeId(actionTsi == -2 ? m_tsi : actionTsi, actionPgci, 0);
 	bool result = false;
-	for (unsigned int obji = 0; obji < m_objects.GetCount(); obji++) {
+	for (unsigned int obji = 0; obji < m_objects.size(); obji++) {
 		MenuObject* obj = m_objects[obji];
+		MenuObjectParam* param = obj->GetImageParam();
+		if (param == NULL)
+			continue;
 		DVDAction& action = obj->GetAction();
-		if (obj->IsButton() && !action.IsCustom() && obj->IsDisplayVideoFrame()	&& action.GetTsi() == actionTsi
-				&& action.GetPgci() == actionPgci && !action.IsMenu()) {
-			result = true; // action is found
-			for (int i = 0; i < obj->GetObjectParamsCount(); i++) {
-				MenuObjectParam* param = obj->GetObjectParam(i);
-				if (param->type == _T("image")) {
-					PgcArray& pgcs = dvd->GetPgcArray(actionTsi == -2 ? m_tsi : actionTsi, false);
-					wxString uri;
-					long int pos = 0;
-					if (actionPgci < (int)pgcs.size()) {
-						uri = pgcs[actionPgci]->GetVideoFrameUri(action.GetChapter());
-						uri.AfterLast(wxT('#')).ToLong(&pos);
-						uri = uri.Find(wxT('#')) >= 0 ? uri.BeforeLast(wxT('#')) : uri;
-					}
-					if (!obj->IsCustomVideoFrame() || uri.length() == 0
-							|| uri != obj->GetParam(param->name).BeforeLast(wxT('#'))) {
-						double dur = obj->GetParamVideoDuration(param->name);
-						obj->SetParamImageVideo(param->name, uri, pos, (int) lround(dur));
-						obj->UpdateSize();
-					}
+		bool isUpdateButton = obj->IsButton() && !action.IsCustom() && obj->IsDisplayVideoFrame()
+				&& action.GetTsi() == actionTsi && action.GetPgci() == actionPgci && !action.IsMenu();
+		MenuObjectParam* imgParam = obj->GetImageParam();
+		bool isUpdateObject = !obj->IsButton() && imgParam != NULL && obj->IsDisplayVideoFrame()
+				&& obj->GetDisplayVobId() == vobId;
+		if (isUpdateButton || isUpdateObject) {
+			result = true; // button/object is found
+			wxString uri;
+			long int pos = 0;
+			if (pgc != NULL) {
+				if (isUpdateButton) {
+					uri = pgc->GetVideoFrameUri(action.GetChapter());
+					uri.AfterLast(wxT('#')).ToLong(&pos);
+					uri = uri.Find(wxT('#')) >= 0 ? uri.BeforeLast(wxT('#')) : uri;
+				} else {
+					uri = pgc->GetVideoFrameUri(-1, -1);
 				}
 			}
+			if (!obj->IsCustomVideoFrame() || uri.length() == 0
+					|| uri != obj->GetParam(param->name).BeforeLast(wxT('#'))) {
+				double dur = obj->GetParamVideoDuration(param->name);
+				obj->SetParamImageVideo(param->name, uri, pos, (int) lround(dur));
+				obj->UpdateSize();
+			}
 		}
 	}
 	return result;
 }
 
+/** Returns object displaying video frame of given title */
+MenuObject* Menu::GetObjectByTitle(int tsi, int pgci, DVD* dvd) {
+	int vobId = DVD::MakeId(tsi == -2 ? m_tsi : tsi, pgci, 0);
+	for (unsigned int obji = 0; obji < m_objects.size(); obji++) {
+		MenuObject* obj = m_objects[obji];
+		if (obj->IsButton() || !obj->IsDisplayVideoFrame() || obj->GetImageParam() == NULL)
+			continue;
+		if (vobId == obj->GetDisplayVobId())
+			return obj;
+	}
+	return NULL;
+}
+
 /** Fix coordinates of buttons if they are out of range */
 void Menu::FixButtonCoordinates() {
 	for (unsigned int obji = 0; obji < m_objects.GetCount(); obji++) {
@@ -764,7 +784,7 @@ void Menu::FixButtonCoordinates() {
 }
 
 /** Checks if buttons overlapping */
-bool Menu::isButtonsOverlapping() {
+bool Menu::isButtonsOverlapping(const wxString& msgPrefix) {
 	for (unsigned int obji = 0; obji < m_objects.GetCount(); obji++) {
 		MenuObject* obj = m_objects[obji];
 		if (!obj->IsButton())
@@ -775,8 +795,11 @@ bool Menu::isButtonsOverlapping() {
 			MenuObject* obj2 = m_objects[obji2];
 			if (!obj2->IsButton())
 				continue;
-			if (obj->GetBBox().Intersects(obj2->GetBBox()))
+			if (obj->GetResultBBox().Intersects(obj2->GetResultBBox())) {
+				wxLogError(msgPrefix + _("%s and %s are overlapping"), obj->GetId(true).c_str(),
+						obj2->GetId(true).c_str());
 				return true;
+			}
 		}
 	}
 	return false;
