@@ -3,14 +3,13 @@
 // Purpose:     The class to store a DVD Menu Object
 // Author:      Alex Thuering
 // Created:	04.11.2006
-// RCS-ID:      $Id: MenuObject.cpp,v 1.50 2014/02/19 21:09:51 ntalex Exp $
+// RCS-ID:      $Id: MenuObject.cpp,v 1.57 2014/05/19 18:37:29 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
 
 #include "DVD.h"
 #include "Menu.h"
-#include "Config.h"
 #include <wxVillaLib/utils.h>
 #include <wxSVG/svg.h>
 #include <wxSVGXML/svgxmlhelpr.h>
@@ -18,6 +17,7 @@
 #include <wx/filename.h>
 #include <wx/regex.h>
 #include <wx/tokenzr.h>
+#include <wx/log.h>
 
 #define BUTTONS_DIR wxFindDataDirectory(_T("buttons"))
 #define OBJECTS_DIR wxFindDataDirectory(_T("objects"))
@@ -50,6 +50,7 @@ MenuObject::MenuObject(Menu* menu, bool vmg, wxString fileName, int x, int y, wx
 	m_autoExecute = false;
 	m_displayVideoFrame = true;
 	m_customVideoFrame = false;
+	m_displayVobId = DVD::MakeId(0, 0, 0);
 
 	m_defaultSize = true;
 	m_defaultWidth.value = m_defaultHeight.value = 0;
@@ -226,8 +227,8 @@ wxString MenuObject::GenerateId(wxString prefix) {
 	return wxT("");
 }
 
-MenuObjectParam* MenuObject::GetObjectParam(wxString name) {
-	for (int i = 0; i < (int) m_params.Count(); i++) {
+MenuObjectParam* MenuObject::GetObjectParam(wxString name) const {
+	for (unsigned int i = 0; i < m_params.size(); i++) {
 		if (m_params[i]->name == name)
 			return m_params[i];
 	}
@@ -240,6 +241,14 @@ MenuObjectParam* MenuObject::GetInitParam() {
 	return GetObjectParam(m_initParameter);
 }
 
+MenuObjectParam* MenuObject::GetImageParam() {
+	for (unsigned int i = 0; i < m_params.size(); i++) {
+		if (m_params[i]->type == wxT("image"))
+			return m_params[i];
+	}
+	return NULL;
+}
+
 int MenuObject::GetChangebaleColourCount(bool drawButtonsOnBackground) {
 	int count = 0;
 	for (int i = 0; i < (int) m_params.Count(); i++) {
@@ -269,7 +278,7 @@ wxSVGSVGElement* MenuObject::AddSymol(wxString id, wxSVGElement* content) {
 	return m_symbol;
 }
 
-void MenuObject::AddUse(wxString id, int x, int y, int width, int height) {
+void MenuObject::AddUse(wxString id, int x, int y, int width, int height, const wxSVGTransformList* transforms) {
 	m_use = new wxSVGUseElement;
 	m_use->SetId(id);
 	m_use->SetHref(wxT("#s_") + id);
@@ -277,6 +286,8 @@ void MenuObject::AddUse(wxString id, int x, int y, int width, int height) {
 	m_use->SetY(y);
 	m_use->SetWidth(width);
 	m_use->SetHeight(height);
+	if (transforms)
+		m_use->SetTransform(*transforms);
 	if (IsButton())
 		m_svg->GetElementById(wxT("buttons"))->AppendChild(m_use);
 	else
@@ -321,49 +332,149 @@ wxString MenuObject::GetId(bool translate) {
 	return (IsButton() ? _("button") : _("object")) + wxString::Format(wxT(" %d"), (int) l);
 }
 
-int MenuObject::GetX() {
+int MenuObject::GetX() const {
 	return m_use->GetX().GetBaseVal();
 }
 void MenuObject::SetX(int value) {
 	m_use->SetX(value);
+	UpdateTransform();
 }
 
-int MenuObject::GetY() {
+int MenuObject::GetY() const {
 	return m_use->GetY().GetBaseVal();
 }
 void MenuObject::SetY(int value) {
 	m_use->SetY(value);
+	UpdateTransform();
 }
 
-int MenuObject::GetWidth() {
+int MenuObject::GetWidth() const {
 	return m_use->GetWidth().GetBaseVal();
 }
 void MenuObject::SetWidth(int value) {
 	m_use->SetWidth(value);
+	UpdateTransform();
 }
 
-int MenuObject::GetHeight() {
+int MenuObject::GetHeight() const {
 	return m_use->GetHeight().GetBaseVal();
 }
 void MenuObject::SetHeight(int value) {
 	m_use->SetHeight(value);
+	UpdateTransform();
 }
 
-wxRect MenuObject::GetBBox() {
+void MenuObject::SetRect(wxRect rect) {
+	m_use->SetX(rect.x);
+	m_use->SetY(rect.y);
+	m_use->SetWidth(rect.width);
+	m_use->SetHeight(rect.height);
+	UpdateTransform();
+}
+
+void MenuObject::UpdateTransform() {
+	if (m_use->GetTransform().GetBaseVal().size() > 0
+			&& m_use->GetTransform().GetBaseVal()[0].GetType() == wxSVG_TRANSFORM_ROTATE) {
+		wxSVGTransform& transform = m_use->GetTransform().GetBaseVal()[0];
+		transform.SetRotate(transform.GetAngle(), GetX() + GetWidth()/2, GetY() + GetHeight()/2);
+	}
+}
+
+double MenuObject::GetAngle() const {
+	MenuObjectParam* param = GetObjectParam(wxT("rotation"));
+	if (param != NULL) {
+		return GetParamDouble(wxT("rotation"));
+	}
+	return m_use->GetTransform().GetBaseVal().size() > 0
+			&& m_use->GetTransform().GetBaseVal()[0].GetType() == wxSVG_TRANSFORM_ROTATE
+			? m_use->GetTransform().GetBaseVal()[0].GetAngle() : 0;
+}
+
+void MenuObject::SetAngle(double angle) {
+	if (angle > 360)
+		angle -= 360;
+	if (angle < 0)
+		angle += 360;
+	MenuObjectParam* param = GetObjectParam(wxT("rotation"));
+	if (param != NULL) {
+		SetParamDouble(wxT("rotation"), angle);
+		return;
+	}
+	if (m_use->GetTransform().GetBaseVal().size() > 0
+			&& m_use->GetTransform().GetBaseVal()[0].GetType() == wxSVG_TRANSFORM_ROTATE) {
+		if (angle != 0) {
+			m_use->GetTransform().GetBaseVal()[0].SetRotate(angle, GetX() + GetWidth()/2, GetY() + GetHeight()/2);
+		} else {
+			m_use->SetTransform(wxSVGTransformList());
+		}
+	} else if (angle != 0) {
+		m_use->SetTransform(wxSVGTransformList());
+		m_use->Rotate(angle, GetX() + GetWidth()/2, GetY() + GetHeight()/2);
+	}
+}
+
+void MenuObject::UpdateMatrix(wxSVGMatrix& matrix) const {
+	m_use->UpdateMatrix(matrix);
+}
+
+wxRect MenuObject::GetBBox() const {
 	return wxRect(GetX(), GetY(), GetWidth(), GetHeight());
 }
 
+wxRect MenuObject::GetResultBBox() const {
+	wxRect bbox = wxRect(GetX(), GetY(), GetWidth(), GetHeight());
+//	wxSVGElement* cElem = (wxSVGElement*) m_symbol->GetElementById(wxT("circle"));
+//	if (cElem != NULL) {
+//		wxSVGSVGElement* viewportElem = new wxSVGSVGElement();
+//		viewportElem->SetWidth(m_use->GetWidth().GetBaseVal());
+//		viewportElem->SetHeight(m_use->GetHeight().GetBaseVal());
+//		cElem->SetViewportElement(viewportElem);
+//		wxSVGRect elemBox = wxSVGLocatable::GetElementResultBBox(cElem);
+//		cElem->SetViewportElement(NULL);
+//		delete viewportElem;
+//		bbox = wxRect(GetX() + elemBox.GetX(), GetY() + elemBox.GetY(), elemBox.GetWidth(), elemBox.GetHeight());
+//	}
+	if (m_use->GetTransform().GetBaseVal().size() > 0
+			&& m_use->GetTransform().GetBaseVal()[0].GetType() == wxSVG_TRANSFORM_ROTATE) {
+		wxSVGTransform& transform = m_use->GetTransform().GetBaseVal()[0];
+		double angle = transform.GetAngle();
+		if (angle != 0) {
+			wxSVGPoint point[4] = {
+					wxSVGPoint(bbox.GetX(), bbox.GetY()).MatrixTransform(transform.GetMatrix()),
+					wxSVGPoint(bbox.GetX() + bbox.GetWidth(), bbox.GetY()).MatrixTransform(transform.GetMatrix()),
+					wxSVGPoint(bbox.GetX(), bbox.GetY() + bbox.GetHeight()).MatrixTransform(transform.GetMatrix()),
+					wxSVGPoint(bbox.GetX() + bbox.GetWidth(), bbox.GetY() + bbox.GetHeight()).MatrixTransform(transform.GetMatrix())
+			};
+			wxSVGPoint p1 = point[0];
+			wxSVGPoint p2 = point[0];
+			for (int i = 1; i < 4; i++) {
+				if (p1.GetX() > point[i].GetX())
+					p1.SetX(point[i].GetX());
+				if (p1.GetY() > point[i].GetY())
+					p1.SetY(point[i].GetY());
+				if (p2.GetX() < point[i].GetX())
+					p2.SetX(point[i].GetX());
+				if (p2.GetY() < point[i].GetY())
+					p2.SetY(point[i].GetY());
+			}
+			return wxRect(p1.GetX(), p1.GetY(), p2.GetX() - p1.GetX(), p2.GetY() - p1.GetY());
+		}
+	}
+	return bbox;
+}
+
 wxRect MenuObject::GetFrameBBox(SubStreamMode mode, bool ignorePadding) {
+	wxRect bbox = GetResultBBox();
 	double fx = mode == ssmPANSCAN ? 4.0/3 : 1.0;
 	double fy = mode == ssmLETTERBOX ? 0.75 : 1.0;
 	if (m_menu != NULL)
 		fy *= (double) m_menu->GetFrameResolution().GetHeight() / m_menu->GetResolution().GetHeight();
-	int width = round(GetWidth()*fx);
-	int height = round(GetHeight()*fy);
+	int width = round(bbox.GetWidth()*fx);
+	int height = round(bbox.GetHeight()*fy);
 	int padY = mode == ssmLETTERBOX && !ignorePadding ? m_menu->GetFrameResolution().GetHeight()*0.125: 0;
 	int cropX = mode == ssmPANSCAN ? m_menu->GetFrameResolution().GetWidth()*0.125 : 0;
-	int x = round((GetX() - cropX)*fx);
-	int y = round(GetY()*fy) + padY;
+	int x = round((bbox.GetX() - cropX)*fx);
+	int y = round(bbox.GetY()*fy) + padY;
 	if (height % 2 == 1)
 		height += y % 2 == 0 ? 1 : -1;
 	if (y % 2 == 1)
@@ -443,7 +554,7 @@ void MenuObject::UpdateSize() {
 		SetY(0);
 }
 
-wxString MenuObject::GetParam(wxString name, wxString attribute) {
+wxString MenuObject::GetParam(wxString name, wxString attribute) const {
 	MenuObjectParam* param = GetObjectParam(name);
 	if (!param)
 		return wxT("");
@@ -550,7 +661,7 @@ void MenuObject::SetParam(wxString name, wxString value, wxString attribute) {
 	}
 }
 
-int MenuObject::GetParamInt(wxString name, wxString attribute) {
+int MenuObject::GetParamInt(wxString name, wxString attribute) const {
 	long lval = 0;
 	GetParam(name, attribute).ToLong(&lval);
 	return lval;
@@ -560,7 +671,7 @@ void MenuObject::SetParamInt(wxString name, int value, wxString attribute) {
 	SetParam(name, wxString::Format(wxT("%d"), value), attribute);
 }
 
-double MenuObject::GetParamDouble(wxString name) {
+double MenuObject::GetParamDouble(wxString name) const {
 	double dval = 0;
 	GetParam(name).ToDouble(&dval);
 	return dval;
@@ -570,13 +681,14 @@ void MenuObject::SetParamDouble(wxString name, double value) {
 	SetParam(name, wxString::Format(wxT("%g"), value));
 }
 
-wxFont MenuObject::GetParamFont(wxString name) {
+wxFont MenuObject::GetParamFont(wxString name) const {
 	MenuObjectParam* param = GetObjectParam(name);
 	if (!param)
 		return wxFont(20, wxFONTFAMILY_DEFAULT, wxNORMAL, wxNORMAL, false);
 	wxSVGElement* elem = (wxSVGElement*) m_symbol->GetElementById(param->element);
-	if (!elem)
+	if (!elem) {
 		return wxFont(20, wxFONTFAMILY_DEFAULT, wxNORMAL, wxNORMAL, false);
+	}
 
 	int size = 20;
 	double dval;
@@ -636,7 +748,7 @@ void MenuObject::SetParamFont(wxString name, wxFont value) {
 		((wxSVGTextElement*) elem)->SetCanvasItem(NULL);
 }
 
-wxColour MenuObject::GetParamColour(wxString name, MenuButtonState state) {
+wxColour MenuObject::GetParamColour(wxString name, MenuButtonState state) const {
 	MenuObjectParam* param = GetObjectParam(name);
 	if (!param)
 		return wxT("");
@@ -721,7 +833,12 @@ void MenuObject::SetParamImageVideo(const wxString& name, const wxString& filena
 	MenuObjectParam* param = GetObjectParam(name);
 	if (!param)
 		return;
-	wxSVGElement* elem = (wxSVGElement*) m_symbol->GetElementById(param->element);
+	MenuObject::SetImageVideoParams(m_symbol, param->element, filename, pos, duration);
+}
+
+void MenuObject::SetImageVideoParams(wxSVGSVGElement* svgElem, const wxString& id, const wxString& filename,
+		long pos, int duration) {
+	wxSVGElement* elem = (wxSVGElement*) svgElem->GetElementById(id);
 	if (!elem || (elem->GetDtd() != wxSVG_IMAGE_ELEMENT && elem->GetDtd() != wxSVG_VIDEO_ELEMENT))
 		return;
 	if (duration <= 0) {
@@ -948,6 +1065,8 @@ wxSvgXmlNode* MenuObject::GetXML(DVDFileType type, DVD* dvd, SubStreamMode mode,
 			rootNode->AddProperty(wxT("displayVideoFrame"), wxT("false"));
 		if (m_customVideoFrame)
 			rootNode->AddProperty(wxT("customVideoFrame"), wxT("true"));
+		if (m_displayVobId != DVD::MakeId(0, 0, 0))
+			rootNode->AddProperty(wxT("vobId"), wxString::Format(_T("%d"), m_displayVobId));
 		break;
 	case SPUMUX_XML: {
 		int mwidth = (int) m_menu->GetFrameResolution().GetWidth() - 1;
@@ -980,14 +1099,7 @@ wxSvgXmlNode* MenuObject::GetXML(DVDFileType type, DVD* dvd, SubStreamMode mode,
 		action.Replace(wxT("vmMenu"), wxT("vmgm menu"));
 		if (dvd->GetPlayAllRegister() != -1)
 			action = wxString::Format(wxT("g%d=%d;"), dvd->GetPlayAllRegister(),
-					GetAction().IsPlayAll() ? (s_config.GetDefPlayAllTitlesets() ? 2 : 1): 0) + action;
-		if (dvd->GetLastMenuRegister() != -1) {
-			int rootMenu = ((Menus&) dvd->GetPgcArray(m_menu->GetTsi(), true)).GetPgciByEntry(wxT("root"));
-			if (action.Contains(wxT("jump menu;")) || action.Contains(wxT("jump menu entry root;"))
-					 || action.Contains(wxString::Format(wxT("jump menu %d;"), rootMenu >= 0 ? rootMenu + 1 : 1))
-					 || s_jumpTitlesetMenu.Matches(action))
-				action = wxString::Format(wxT("g%d=0;"), dvd->GetLastMenuRegister()) + action;
-		}
+					GetAction().IsPlayAll() ? (GetAction().IsPlayAllTitlesets() ? 2 : 1): 0) + action;
 		if (m_menu->GetRememberLastButton()) {
 			int reg = m_menu->GetRememberLastButtonRegister();
 			if (reg == -1)
@@ -1085,6 +1197,8 @@ bool MenuObject::PutXML(wxSvgXmlNode* node) {
 	m_keepAspectRatio = node->GetPropVal(wxT("keepAspectRatio"), &val) && (val == wxT("true") || val == wxT("1"));
 	m_displayVideoFrame = !node->GetPropVal(wxT("displayVideoFrame"), &val) || (val != wxT("false") && val != wxT("0"));
 	m_customVideoFrame = node->GetPropVal(wxT("customVideoFrame"), &val) && (val == wxT("true") || val == wxT("1"));
+	if (node->GetPropVal(wxT("vobId"), &val) && val.ToLong(&lval))
+		m_displayVobId = lval;
 
 	// paste button
 	wxSvgXmlNode* svgNode = XmlFindNode(node, wxT("svg"));
@@ -1101,10 +1215,8 @@ bool MenuObject::PutXML(wxSvgXmlNode* node) {
 				child = child->GetNext();
 			}
 			wxSVGUseElement* useElem = (wxSVGUseElement*) XmlFindNode(root, wxT("use"));
-			AddUse(m_id, useElem->GetX().GetBaseVal(),
-					useElem->GetY().GetBaseVal(),
-					useElem->GetWidth().GetBaseVal(),
-					useElem->GetHeight().GetBaseVal());
+			AddUse(m_id, useElem->GetX().GetBaseVal(), useElem->GetY().GetBaseVal(), useElem->GetWidth().GetBaseVal(),
+					useElem->GetHeight().GetBaseVal(), &useElem->GetTransform().GetBaseVal());
 		}
 	}
 
