@@ -3,7 +3,7 @@
 // Purpose:     DVD menu button properties dialog
 // Author:      Alex Thuering
 // Created:	20.11.2003
-// RCS-ID:      $Id: MenuObjectPropDlg.cpp,v 1.76 2014/03/07 13:19:23 ntalex Exp $
+// RCS-ID:      $Id: MenuObjectPropDlg.cpp,v 1.81 2015/01/25 18:17:53 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -68,6 +68,7 @@ MenuObjectPropDlg::MenuObjectPropDlg(wxWindow* parent, wxString id, bool multObj
 	m_imageEditIdx = -1;
 	m_imageRadio = NULL;
 	m_videoFrameRadio = NULL;
+	m_videoChoice = NULL;
 	m_videoFrameBt = NULL;
 	m_customActionEdit = NULL;
 	m_widthEdit = NULL;
@@ -123,7 +124,13 @@ void MenuObjectPropDlg::CreatePropPanel(wxSizer* sizer) {
 		AddChoiceProp(jumpSizer, wxT(""), wxT(""), wxArrayString(), -1, true, CHAPTER_CHOICE_ID);
 		m_chapterChoice = (wxChoice*) m_controls[m_controls.Count()-1];
 		UpdateChapters();
-		AddCheckProp(jumpSizer, _("Play all titles"), action.IsPlayAll());
+		BeginCheckGroup(jumpSizer, _("Play all titles"), action.IsPlayAll());
+		wxArrayString labels;
+		labels.Add(_("single titleset"));
+		labels.Add(_("all titlesets"));
+		jumpSizer->Add(AddChoiceProp(labels[action.IsPlayAllTitlesets() ? 1 : 0], labels));
+		EndGroup();
+		
 		grid->Add(jumpSizer);
 		// customAction
 		if (!customAction.length()) {
@@ -139,7 +146,7 @@ void MenuObjectPropDlg::CreatePropPanel(wxSizer* sizer) {
 				CUSTOM_ACTION_RADIO_ID);
 		AddTextProp(grid, wxT(""), customAction);
 		m_customActionEdit = (wxTextCtrl*) m_controls[m_controls.Count()-1];
-		mainSizer->Add(grid, 0, wxEXPAND|wxBOTTOM, 8);
+		mainSizer->Add(grid, 0, wxEXPAND|wxBOTTOM, 4);
 		wxCommandEvent evt;
 		if (customAction.length())
 			OnCustomActionSelected(evt);
@@ -147,7 +154,7 @@ void MenuObjectPropDlg::CreatePropPanel(wxSizer* sizer) {
 			OnJumpActionSelected(evt);
 
 		// audio & subtitle
-		wxArrayString labels;
+		labels.Clear();
 		labels.Add(_("last selected"));
 		for (int i = 0; i < (int) m_dvd->GetAudioStreamCount(); i++)
 			labels.Add(_("track") + wxString::Format(wxT(" %d"), i + 1));
@@ -180,7 +187,7 @@ void MenuObjectPropDlg::CreatePropPanel(wxSizer* sizer) {
 		grid->Add(10,10);
 		AddNavigationProp(grid, nbDOWN);
 		grid->Add(10,10);
-		mainSizer->Add(grid, 0, wxEXPAND|wxALL, 4);
+		mainSizer->Add(grid, 0, wxEXPAND|wxTOP|wxBOTTOM, 4);
 		AddStaticLine(mainSizer, _("Look"));
 	}
     CreateLook(mainSizer, grid);
@@ -195,6 +202,9 @@ void MenuObjectPropDlg::CreateLook(wxBoxSizer* mainSizer, wxFlexGridSizer* grid)
     bool lastChangeable = false;
     for (int i=0; i<m_object->GetObjectParamsCount(); i++) {
 		MenuObjectParam* param = m_object->GetObjectParam(i);
+		if (param->name == wxT("rotation")) {
+			continue;
+		}
 
 		if (i == 0 || param->changeable != lastChangeable) {
 			if (param->changeable) {
@@ -271,50 +281,7 @@ void MenuObjectPropDlg::CreateLook(wxBoxSizer* mainSizer, wxFlexGridSizer* grid)
 				if (m_multObjects && param->attribute.Find(wxT('#')) != wxNOT_FOUND)
 					GetLastControl()->Enable(false);
 			} else if (param->type == _T("image") && !m_multObjects) {
-				wxString imageFile = m_object->GetParam(param->name);
-				if (m_object->IsButton()) {
-					bool hasVideo = GetVideoFilename(false).length();
-					wxString fname = imageFile.Find(wxT('#')) != -1 ? imageFile.BeforeLast(wxT('#')) : imageFile;
-					bool image = !m_displayVideoFrame || !hasVideo || fname != GetVideoFilename(false);
-					AddRadioProp(grid, wxString(_("Image")) + wxT(":"), image, wxRB_GROUP, false, IMAGE_RADIO_ID);
-					m_imageRadio = (wxRadioButton*) GetLastControl();
-					wxString wildcard = _("Image Files ") + wxImage::GetImageExtWildcard()
-						+ wxT("|") + wxString(_("All Files")) + wxT(" (*.*)|*.*"); 
-					AddFileProp(grid, wxT(""), wxString(image ? imageFile : wxT("")), wxFD_OPEN, wxT("..."), wildcard);
-					m_imageEdit = (wxTextCtrl*) GetLastControl();
-					m_imageEditIdx = GetLastControlIndex();
-					AddRadioProp(grid, wxString(_("Video")) + wxT(":"), !image, 0, false, VIDEOFRAME_RADIO_ID);
-					m_videoFrameRadio = (wxRadioButton*) GetLastControl();
-					m_videoFrameRadio->Enable(hasVideo);
-					m_videoFrameBt = new wxButton(this, VIDEOFRAME_BT_ID, wxT("..."));
-					int h = m_videoFrameBt->GetSize().GetHeight() > 24 ? m_videoFrameBt->GetSize().GetHeight() : 24;
-					m_videoFrameBt->SetSizeHints(h, h, h, h);
-					grid->Add(m_videoFrameBt);
-					wxCommandEvent evt;
-					OnImageRadio(evt);
-					// default video position
-					wxString url = GetVideoFilename(true);
-					if (url.length())
-						url.AfterLast(wxT('#')).ToLong(&m_defaultPos);
-					// video position
-					if (!image) {
-						m_videoPos = lround(m_object->GetParamVideoClipBegin(param->name) * 1000);
-						if (!image && imageFile.Find(wxT('#')) != -1) {
-							wxString vf = imageFile.AfterLast(wxT('#'));
-							if (vf.length() > 0)
-								vf.ToLong(&m_videoPos);
-						}
-					} else
-						m_videoPos = m_defaultPos;
-					// video duration
-					m_videoDuration = m_object->GetParamVideoDuration(param->name);
-				} else {
-					AddFileProp(grid, title, imageFile, wxFD_OPEN,
-						wxT("..."), _("Image Files ") + wxImage::GetImageExtWildcard()
-						+ wxT("|") + wxString(_("All Files")) + wxT(" (*.*)|*.*"));
-					if (m_multObjects)
-						GetLastControl()->Enable(false);
-				}
+				CreateImageCrtls(grid, title, param);
 			} else if (param->type == _T("colour")) {
 				int opacity = 100;
 				wxString opacityStr = m_object->GetParam(param->name, wxT("-opacity"));
@@ -325,52 +292,138 @@ void MenuObjectPropDlg::CreateLook(wxBoxSizer* mainSizer, wxFlexGridSizer* grid)
 				}
 				AddColourProp(grid, title, m_object->GetParamColour(param->name), opacity);
 			} else if (param->type == wxT("shadow")) {
-				bool shadow = m_object->GetParam(param->name, wxT("visibility")) != wxT("hidden");
-				BeginCheckGroup(grid, title, shadow, false);
-				wxSizer* shadowSizer = new wxBoxSizer(wxHORIZONTAL);
-				grid->Add(shadowSizer);
-				int opacity = 100;
-				wxString opacityStr = m_object->GetParam(param->name, wxT("-opacity"));
-				if (opacityStr.length() > 0) {
-					double dval;
-					opacityStr.ToDouble(&dval);
-					opacity = (int) (dval*100);
-				}
-				AddColourProp(shadowSizer, wxT(""), m_object->GetParamColour(param->name), opacity);
-				shadowSizer->AddSpacer(8);
-				AddText(shadowSizer, _("Offset:"));
-				shadowSizer->AddSpacer(4);
-				AddSpinProp(shadowSizer, wxT(""), m_object->GetParamInt(param->name, wxT("x")), -999, 999, 46, wxT(""), false);
-				AddSpinProp(shadowSizer, wxT(""), m_object->GetParamInt(param->name, wxT("y")), -999, 999, 46, wxT(""), false);
-				shadowSizer->AddSpacer(4);
-				wxSVGElement* filter = m_object->GetElementById(param->element + wxT("Filter"));
-				if (filter && ((wxSVGElement*)filter->GetFirstChild())->GetDtd() == wxSVG_FEGAUSSIANBLUR_ELEMENT) {
-					wxSVGFEGaussianBlurElement* blur = (wxSVGFEGaussianBlurElement*) filter->GetFirstChild();
-					AddText(shadowSizer, _("Deviation:"));
-					shadowSizer->AddSpacer(4);
-					AddSpinDoubleProp(shadowSizer, wxT(""), blur->GetStdDeviationX(), 0, 99, 46);
-				}
-				EndGroup();
+				CreateShadowCtrls(grid, title, param);
 			}
 		}
 	}
 }
 
+void MenuObjectPropDlg::CreateImageCrtls(wxFlexGridSizer* grid, const wxString& title, MenuObjectParam* param) {
+	wxString imageFile = m_object->GetParam(param->name);
+	wxString fname = imageFile.Find(wxT('#')) != -1 ? imageFile.BeforeLast(wxT('#')) : imageFile;
+	if (!m_object->IsButton()) {
+		m_videoChoice = AddChoiceProp(wxT(""), wxArrayString());
+		int sel = 0;
+		for (unsigned int tsi = 0; tsi < m_dvd->GetTitlesets().size(); tsi++) {
+			Titleset* ts = m_dvd->GetTitlesets()[tsi];
+			for (unsigned int pgci = 0; pgci < ts->GetTitles().size(); pgci++) {
+				wxString label = _("title") + wxString::Format(wxT(" %d"), pgci + 1);
+				if (m_dvd->GetTitlesets().size() > 1)
+					label = _("titleset") + wxString::Format(wxT(" %d "), tsi + 1) + label;
+				int id = DVD::MakeId(tsi, pgci, 0, false);
+				m_videoChoice->Append(label, (void*)(intptr_t) id);
+				if (id == m_object->GetDisplayVobId()) {
+					sel = m_videoChoice->GetCount() - 1;
+				}
+			}
+		}
+		if (m_videoChoice->GetCount() > 0)
+			m_videoChoice->SetSelection(sel);
+	}
+	bool hasVideo = GetVideoFilename(false).length();
+	// image
+	bool image = !m_displayVideoFrame || !hasVideo || fname != GetVideoFilename(false);
+	AddRadioProp(grid, wxString(_("Image")) + wxT(":"), image, wxRB_GROUP, false, IMAGE_RADIO_ID);
+	m_imageRadio = (wxRadioButton*) GetLastControl();
+	wxString wildcard = _("Image Files ") + wxImage::GetImageExtWildcard()
+		+ wxT("|") + wxString(_("All Files")) + wxT(" (*.*)|*.*"); 
+	AddFileProp(grid, wxT(""), wxString(image ? imageFile : wxT("")), wxFD_OPEN, wxT("..."), wildcard);
+	m_imageEdit = (wxTextCtrl*) GetLastControl();
+	m_imageEditIdx = GetLastControlIndex();
+	// video frame
+	AddRadioProp(grid, wxString(_("Video")) + wxT(":"), !image, 0, false, VIDEOFRAME_RADIO_ID);
+	m_videoFrameRadio = (wxRadioButton*) GetLastControl();
+	m_videoFrameRadio->Enable(hasVideo);
+	wxBoxSizer* videoFrameSizer = new wxBoxSizer(wxHORIZONTAL);
+	if (!m_object->IsButton()) {
+		videoFrameSizer->Add(m_videoChoice, 0, wxALIGN_CENTER_VERTICAL);
+	}
+	m_videoFrameBt = new wxButton(this, VIDEOFRAME_BT_ID, wxT("..."));
+	int h = m_videoFrameBt->GetSize().GetHeight() > 24 ? m_videoFrameBt->GetSize().GetHeight() : 24;
+	m_videoFrameBt->SetSizeHints(h, h, h, h);
+	videoFrameSizer->Add(m_videoFrameBt);
+	grid->Add(videoFrameSizer);
+	wxCommandEvent evt;
+	OnImageRadio(evt);
+	// default video position
+	if (m_object->IsButton()) {
+		wxString url = GetVideoFilename(true);
+		if (url.length()) {
+			url.AfterLast(wxT('#')).ToLong(&m_defaultPos);
+		}
+	} else {
+		m_defaultPos = 0;
+	}
+	// video position
+	if (!image) {
+		m_videoPos = lround(m_object->GetParamVideoClipBegin(param->name) * 1000);
+		if (!image && imageFile.Find(wxT('#')) != -1) {
+			wxString vf = imageFile.AfterLast(wxT('#'));
+			if (vf.length() > 0)
+				vf.ToLong(&m_videoPos);
+		}
+	} else
+		m_videoPos = m_defaultPos;
+	// video duration
+	m_videoDuration = m_object->GetParamVideoDuration(param->name);
+}
+
+
+void MenuObjectPropDlg::CreateShadowCtrls(wxFlexGridSizer* grid, const wxString& title, MenuObjectParam* param) {
+	bool shadow = m_object->GetParam(param->name, wxT("visibility")) != wxT("hidden");
+	BeginCheckGroup(grid, title, shadow, false);
+	wxSizer* shadowSizer = new wxBoxSizer(wxHORIZONTAL);
+	grid->Add(shadowSizer);
+	int opacity = 100;
+	wxString opacityStr = m_object->GetParam(param->name, wxT("-opacity"));
+	if (opacityStr.length() > 0) {
+		double dval;
+		opacityStr.ToDouble(&dval);
+		opacity = (int) (dval*100);
+	}
+	AddColourProp(shadowSizer, wxT(""), m_object->GetParamColour(param->name), opacity);
+	shadowSizer->AddSpacer(8);
+	AddText(shadowSizer, _("Offset:"));
+	shadowSizer->AddSpacer(4);
+	AddSpinProp(shadowSizer, wxT(""), m_object->GetParamInt(param->name, wxT("x")), -999, 999, 46, wxT(""), false);
+	AddSpinProp(shadowSizer, wxT(""), m_object->GetParamInt(param->name, wxT("y")), -999, 999, 46, wxT(""), false);
+	shadowSizer->AddSpacer(4);
+	wxSVGElement* filter = m_object->GetElementById(param->element + wxT("Filter"));
+	if (filter && ((wxSVGElement*)filter->GetFirstChild())->GetDtd() == wxSVG_FEGAUSSIANBLUR_ELEMENT) {
+		wxSVGFEGaussianBlurElement* blur = (wxSVGFEGaussianBlurElement*) filter->GetFirstChild();
+		AddText(shadowSizer, _("Deviation:"));
+		shadowSizer->AddSpacer(4);
+		AddSpinDoubleProp(shadowSizer, wxT(""), blur->GetStdDeviationX(), 0, 99, 46);
+	}
+	EndGroup();
+}
+
 void MenuObjectPropDlg::CreateLocAndSize(wxBoxSizer* mainSizer) {
 	wxSizer* hSizer = new wxBoxSizer(wxHORIZONTAL);
 	mainSizer->Add(hSizer, 0, wxTOP, 8);
 
+	wxSizer* vSizer = new wxBoxSizer(wxVERTICAL);
+	hSizer->Add(vSizer);
+
 	// object location
-	wxSizer* grpSizer = BeginGroup(hSizer, _("Location"));
+	wxSizer* grpSizer = BeginGroup(vSizer, _("Location"));
 	wxFlexGridSizer* grid = new wxFlexGridSizer(2, 4, 16);
 	wxSize menuSize = m_menu->GetResolution();
 	AddSpinProp(grid, _("X:"), m_object->GetX(), m_object->IsButton() ? 0 : -menuSize.GetWidth(), menuSize.GetWidth()-8);
 	AddSpinProp(grid, _("Y:"), m_object->GetY(), m_object->IsButton() ? 0 : -menuSize.GetHeight(), menuSize.GetHeight()-8);
 	grpSizer->Add(grid, 0, wxALL, 4);
 	EndGroup();
-	hSizer->AddSpacer(8);
+	vSizer->AddSpacer(8);
+	
+	// object rotation
+	grpSizer = BeginGroup(vSizer, _("Rotation"));
+	grid = new wxFlexGridSizer(2, 4, 16);
+	AddSpinDoubleProp(grid, _("Angle:"), m_object->GetAngle(), 0, 360);
+	grpSizer->Add(grid, 0, wxALL, 4);
+	EndGroup();
 
 	// object size
+	hSizer->AddSpacer(8);
 	grpSizer = BeginGroup(hSizer, _("Size"), _("Custom"), !m_object->IsDefaultSize());
 	grid = new wxFlexGridSizer(2, 4, 16);
 	AddSpinProp(grid, _("Width:"), m_object->GetWidth(), 0, m_menu->GetResolution().GetWidth());
@@ -583,19 +636,29 @@ wxString MenuObjectPropDlg::GetVideoFilename(bool withTimestamp, long position)
 	int tsi = -1;
 	int pgci = 0;
 	int chapter = 0;
-	if (!GetBool(0)) { // custom action
-		DVDAction action(m_object->GetAction());
-		action.SetCustom(m_customActionEdit->GetValue());
-		int id = action.FindFirstJump(m_tsi);
-		if (id >= 0) {
+	if (m_object->IsButton()) {
+		if (!GetBool(0)) { // custom action
+			DVDAction action(m_object->GetAction());
+			action.SetCustom(m_customActionEdit->GetValue());
+			int id = action.FindFirstJump(m_tsi);
+			if (id >= 0) {
+				tsi = DVD::GetTsi(id);
+				pgci = DVD::GetPgci(id);
+				chapter = DVD::GetVobi(id);
+			}
+		} else if (!IsSelectedMenu()) {
+			tsi = GetSelectedTsi();
+			pgci = GetSelectedPgci();
+			chapter = GetSelectedChapter();
+		}
+	} else {
+		if (m_videoChoice != NULL) {
+			int id = (intptr_t) m_videoChoice->GetClientData(m_videoChoice->GetSelection());
 			tsi = DVD::GetTsi(id);
 			pgci = DVD::GetPgci(id);
-			chapter = DVD::GetVobi(id);
+		} else {
+			tsi = 0;
 		}
-	} else if (!IsSelectedMenu()) {
-		tsi = GetSelectedTsi();
-		pgci = GetSelectedPgci();
-		chapter = GetSelectedChapter();
 	}
 
 	if (tsi < 0 || tsi >= (int) m_dvd->GetTitlesets().size())
@@ -613,6 +676,8 @@ void MenuObjectPropDlg::OnImageRadio(wxCommandEvent& evt){
 		button->Enable(m_imageRadio->GetValue());
 	if (m_videoFrameRadio->IsEnabled())
 		m_displayVideoFrame = m_videoFrameRadio->GetValue();
+	if (m_videoChoice != NULL)
+		m_videoChoice->Enable(m_videoFrameRadio->GetValue());
 	m_videoFrameBt->Enable(m_videoFrameRadio->GetValue());
 }
 
@@ -698,15 +763,16 @@ void MenuObjectPropDlg::AddNavigationProp(wxSizer* sizer, NavigationButton navBu
 
 bool MenuObjectPropDlg::SetValues() {
 	// check Action
+	int customRadioIdx = 5;
 	if (m_object->IsButton() && !m_multObjects) {
-		if (GetBool(4) && GetString(5).length() == 0) { // empty custom action
+		if (GetBool(customRadioIdx) && GetString(customRadioIdx + 1).length() == 0) { // empty custom action
 			wxMessageBox(_("Please enter the action command."),
 			GetTitle(), wxOK|wxICON_ERROR, this);
 			return false;
 		}
-		if (GetBool(4)) {
+		if (GetBool(customRadioIdx)) {
 			DVDAction action(m_object->GetAction());
-			action.SetCustom(GetString(5));
+			action.SetCustom(GetString(customRadioIdx + 1));
 			if (!action.IsValid(m_dvd, m_tsi, m_pgci, true, m_object->GetId(), true, false)
 					&& !s_config.GetAcceptInvalidActions())
 				return false;
@@ -729,6 +795,7 @@ bool MenuObjectPropDlg::SetValues() {
 		action.SetChapter(GetSelectedChapter());
 		n += 3;
 		action.SetPlayAll(GetBool(n++));
+		action.SetPlayAllTitlesets(GetInt(n++) == 1);
 		if (GetBool(n++)) {
 			if (GetString(n) == wxT("jump title 1;")) {
 				action.SetTsi(-2);
@@ -762,6 +829,9 @@ bool MenuObjectPropDlg::SetValues() {
 	// set look parameters
 	for (int i = 0; i < m_object->GetObjectParamsCount(); i++) {
 		MenuObjectParam* param = m_object->GetObjectParam(i);
+		if (param->name == wxT("rotation")) {
+			continue;
+		}
 		if (param->changeable && param->type == _T("colour")) {
 			m_object->SetParamColour(param->name, GetColour(n++));
 			m_object->SetParamColour(param->name, GetColour(n++), mbsHIGHLIGHTED);
@@ -793,31 +863,34 @@ bool MenuObjectPropDlg::SetValues() {
 				} else {
 					n += 3;
 				}
-			} else if (param->type == _T("string"))
+			} else if (param->type == _T("string")) {
 				m_object->SetParam(param->name, GetString(n++));
-			else if (param->type.Mid(0, 7) == _T("integer"))
+			} else if (param->type.Mid(0, 7) == _T("integer")) {
 				m_object->SetParamInt(param->name, GetInt(n++));
-			else if (param->type.Mid(0, 7) == _T("decimal"))
+			} else if (param->type.Mid(0, 7) == _T("decimal")) {
 				m_object->SetParamDouble(param->name, GetDouble(n++));
-			else if (param->type == _T("percent"))
+			} else if (param->type == _T("percent")) {
 				m_object->SetParamDouble(param->name, ((double)GetInt(n++))/100);
-			else if (param->type == _T("colour")) {
+			} else if (param->type == _T("colour")) {
 				m_object->SetParamColour(param->name, GetColour(n++));
 				wxString opacity = wxString::Format(wxT("%g"), (double) GetInt(n++) / 100);
 				m_object->SetParam(param->name, opacity, wxT("-opacity"));
 			} else if (param->type == _T("image") && !m_multObjects) {
-				if (m_object->IsButton()) {
-					m_object->SetDisplayVideoFrame(m_displayVideoFrame);
-					bool image = GetBool(n++); // image radio button
-					wxString imgFile = GetString(n++);
-					n++; // video radio button
-					if (!image) {
-						m_object->SetCustomVideoFrame(m_videoPos != m_defaultPos);
-						m_object->SetParamImageVideo(param->name, GetVideoFilename(false), m_videoPos, m_videoDuration);
-					} else
-						m_object->SetParamImageVideo(param->name, imgFile, -1, -1);
-				} else
-					m_object->SetParam(param->name, GetString(n++));
+				m_object->SetDisplayVideoFrame(m_displayVideoFrame);
+				n += m_object->IsButton() ? 0 : 1; // video choice
+				bool image = GetBool(n++); // image radio button
+				wxString imgFile = GetString(n++);
+				n++; // video radio button
+				if (!image) {
+					m_object->SetCustomVideoFrame(m_videoPos != m_defaultPos);
+					m_object->SetParamImageVideo(param->name, GetVideoFilename(false), m_videoPos, m_videoDuration);
+					if (!m_object->IsButton()) {
+						m_object->SetDisplayVobId((intptr_t) m_videoChoice->GetClientData(m_videoChoice->GetSelection()));
+					}
+				} else {
+					m_object->SetParamImageVideo(param->name, imgFile, -1, -1);
+					m_object->SetDisplayVobId(DVD::MakeId(0, 0, 0));
+				}
 			} else if (param->type == wxT("shadow")) {
 				m_object->SetParam(param->name, GetBool(n++) ? wxT("visible") : wxT("hidden"), wxT("visibility"));
 				m_object->SetParamColour(param->name, GetColour(n++));
@@ -839,6 +912,9 @@ bool MenuObjectPropDlg::SetValues() {
 		// set position
 		m_object->SetX(GetInt(n++));
 		m_object->SetY(GetInt(n++));
+		
+		// set angle
+		m_object->SetAngle(GetDouble(n++));
 
 		// set size
 		m_object->SetDefaultSize(!GetBool(n++));
