@@ -3,7 +3,7 @@
 // Purpose:     DVD menu button properties dialog
 // Author:      Alex Thuering
 // Created:	20.11.2003
-// RCS-ID:      $Id: MenuObjectPropDlg.h,v 1.23 2014/02/04 13:37:26 ntalex Exp $
+// RCS-ID:      $Id: MenuObjectPropDlg.h,v 1.24 2014/04/06 10:26:57 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -31,6 +31,8 @@ private:
 	void CreatePropPanel(wxSizer* sizer);
     void CreateLook(wxBoxSizer* mainSizer, wxFlexGridSizer* grid);
 	void CreateLocAndSize(wxBoxSizer* mainSizer);
+	void CreateImageCrtls(wxFlexGridSizer* grid, const wxString& title, MenuObjectParam* param);
+	void CreateShadowCtrls(wxFlexGridSizer* grid, const wxString& title, MenuObjectParam* param);
 	
 	wxChoice* m_targetChoice;
 	wxChoice* m_chapterChoice;
@@ -57,6 +59,7 @@ private:
 	int m_imageEditIdx;
 	wxRadioButton* m_imageRadio;
 	wxRadioButton* m_videoFrameRadio;
+	wxChoice* m_videoChoice;
 	wxButton* m_videoFrameBt;
 	wxString GetVideoFilename(bool withTimestamp = false, long position = -1);
 	void OnImageRadio(wxCommandEvent& evt);
