@@ -3,7 +3,7 @@
 // Purpose:     DVD menu properties dialog
 // Author:      Alex Thuering
 // Created:     25.04.2004
-// RCS-ID:      $Id: MenuPropDlg.cpp,v 1.47 2014/03/11 12:11:12 ntalex Exp $
+// RCS-ID:      $Id: MenuPropDlg.cpp,v 1.48 2014/09/20 05:54:03 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -65,12 +65,27 @@ MenuPropDlg::~MenuPropDlg() {
 	VECTOR_CLEAR(m_actions, DVDAction)
 }
 
+/**
+ * Creates properties panel.
+ */
 void MenuPropDlg::CreatePropPanel(wxSizer* sizer) {
+	bool loop = m_vob->GetPause() == 0 && m_pgc->GetPostCommands() == wxT("jump cell 1;");
+	CreateVobGroup(sizer, loop);
+	CreateButtonsGroup(sizer);
+	CreateMenuGroup(sizer, loop);
+}
+
+void MenuPropDlg::CreateVobGroup(wxSizer* sizer, bool loop) {
+	wxSizer* grpSizer = BeginGroup(sizer, _("Video object"));
+	wxFlexGridSizer* grid = new wxFlexGridSizer(2, 4, 6);
+	grid->AddGrowableCol(1);
+	
+	// format
+	AddText(grid, _("Format:"));
 	wxSizer* formatSizer = new wxBoxSizer(wxHORIZONTAL);
-	AddText(formatSizer, _("Format:"));
 	wxArrayString formats = DVD::GetVideoFormatLabels(false, false, true);
 	int vf = m_menu->GetVideoFormat() >= 2 ? m_menu->GetVideoFormat() - 2 : 0;
-	formatSizer->Add(AddChoiceProp(formats[vf], formats), 0, wxEXPAND | wxLEFT, 4);
+	formatSizer->Add(AddChoiceProp(formats[vf], formats), 0, wxEXPAND);
 	formatSizer->AddSpacer(4);
 	formats = DVD::GetAspectRatioLabels();
 	int ar = m_menu->GetAspectRatio() >= 1 ? m_menu->GetAspectRatio() - 1 : 0;
@@ -81,24 +96,17 @@ void MenuPropDlg::CreatePropPanel(wxSizer* sizer) {
 	formatSizer->Add(AddChoiceProp(wsFormats[m_video->GetWidescreen()], wsFormats), 0, wxEXPAND);
 	m_wsFormat = (wxChoice*) GetLastControl();
 	formatSizer->AddStretchSpacer(1);
-	sizer->Add(formatSizer, 0, wxEXPAND | wxALL, 6);
+	grid->Add(formatSizer, 0, wxEXPAND);
 	wxCommandEvent evt;
 	OnChangeAspect(evt);
 	
-	CreateBackgroundGroup(sizer);
-	CreateButtonsGroup(sizer);
-	bool loop = m_vob->GetPause() == 0 && m_pgc->GetPostCommands() == wxT("jump cell 1;");
-	CreateVobGroup(sizer, loop);
-	CreateMenuGroup(sizer, loop);
-}
-
-void MenuPropDlg::CreateBackgroundGroup(wxSizer* sizer) {
-	wxSizer* grpSizer = BeginGroup(sizer, _("Background"));
-	wxFlexGridSizer* grid = new wxFlexGridSizer(2, 4, 16);
-	grid->AddGrowableCol(1);
-	// Image
-	AddFileProp(grid, _("Image:"), m_menu->GetBackground(), wxFD_OPEN, wxT("..."),
-			_("Image Files ") + wxImage::GetImageExtWildcard()
+	// Background
+	wxString video = wxThumbnails::GetVideoExtWildcard();
+	wxString imageExt = wxImage::GetImageExtWildcard();
+	AddFileProp(grid, _("Background:"), m_menu->GetBackground(), wxFD_OPEN, wxT("..."),
+			_("Image and Video Files") + wxString::Format(wxT("|%s%s|"), video.c_str(), imageExt.AfterLast(wxT('|')).c_str())
+			+ _("Video Files") + wxString::Format(wxT(" (%s)|%s|"), video.c_str(), video.c_str())
+			+ _("Image Files ") + imageExt
 			+ wxT("|") + wxString(_("All Files")) + wxT(" (*.*)|*.*"));
 	// Keep aspect ratio
 	grid->AddSpacer(8);
@@ -117,24 +125,52 @@ void MenuPropDlg::CreateBackgroundGroup(wxSizer* sizer) {
 	alignYStrings.Add(_("Y Mid"));
 	alignYStrings.Add(_("Y Max"));
 	int alignY = keepAspectRatio ? (m_menu->GetBackgroundAlign() - wxSVG_PRESERVEASPECTRATIO_XMINYMIN) / 3 : 1;
-	cbSizer->Add(AddChoiceProp(alignYStrings[alignY], alignYStrings));
+	cbSizer->Add(AddChoiceProp(alignYStrings[alignY], alignYStrings), 0, wxLEFT, 4);
 	wxArrayString meetStrings;
 	meetStrings.Add(_("Meet"));
 	meetStrings.Add(_("Slice"));
 	int meet = m_menu->GetBackgroundMeetOrSlice() == wxSVG_MEETORSLICE_SLICE ? 1 : 0;
-	cbSizer->Add(AddChoiceProp(meetStrings[meet], meetStrings));
+	cbSizer->Add(AddChoiceProp(meetStrings[meet], meetStrings), 0, wxLEFT, 4);
 	cbSizer->AddStretchSpacer(1);
 	grid->Add(cbSizer, 0, wxEXPAND|wxALL, 4);
 	EndGroup();
 	// Colour
-	AddColourProp(grid, _("Colour:"), m_menu->GetBackgroundColour());
+	AddColourProp(grid, wxT(" "), m_menu->GetBackgroundColour());
+	
+	// audio file
+	wxString audioFile = m_vob->GetAudioFilenames().size() ? m_vob->GetAudioFilenames()[0] : wxT("");
+	wxString audio = wxThumbnails::GetAudioExtWildcard();
+	AddFileProp(grid, _("Audio:"), audioFile, wxFD_OPEN, wxT("..."),
+			_("Audio Files") + wxString::Format(wxT(" (%s)|%s|"), audio.c_str(), audio.c_str())
+			+ _("All Files") + wxString(wxT(" (*.*)|*.*")), AUDIO_CTRL_ID);
+	m_audioCtrlIdx = GetLastControlIndex();
+	// audio format
+	grid->AddSpacer(8);
+	Stream* stream = audioFile.length() > 0 ? m_vob->GetStreams()[m_vob->GetStreams().size() - 1] : NULL;
+	int af = stream != NULL ? stream->GetAudioFormat() - 1 : afCOPY - 1;
+	formats = DVD::GetAudioFormatLabels(true);
+	wxSizer* audioFormatSizer = AddChoiceProp(grid, wxT(""), formats[af], formats, 0, false);
+	m_audioFormat = (wxChoice*) GetLastControl();
+	m_audioFormat->Enable(audioFile.length() > 0);
+	wxArrayString labels = DVD::GetAudioLanguageCodes();
+	if (m_langCodes->GetCount() < 1)
+		m_langCodes->Add(s_config.GetDefAudioLanguage());
+	audioFormatSizer->AddSpacer(4);
+	AddChoiceProp(audioFormatSizer, wxT(""), (*m_langCodes)[0], labels, 0, false);
+	// pause and loop
+	wxSizer* pSizer = AddSpinProp(grid, _("Pause:"), m_vob->GetPause(), -1, 254, 100, _("sec"),false);
+	m_pauseCtrl = (wxSpinCtrl*) GetLastControl();
+	m_pauseCtrl->Enable(!loop);
+	pSizer->AddSpacer(8);
+	AddCheckProp(pSizer, _("Loop"), loop, false, LOOP_CB_ID);
+	
 	grpSizer->Add(grid, 0, wxEXPAND|wxALL, 4);
 	sizer->AddSpacer(6);
 }
 
 void MenuPropDlg::CreateButtonsGroup(wxSizer* sizer) {
 	wxSizer* grpSizer = BeginGroup(sizer, _("Buttons"));
-	wxFlexGridSizer* grid = new wxFlexGridSizer(2, 4, 16);
+	wxFlexGridSizer* grid = new wxFlexGridSizer(2, 4, 6);
 	grid->AddGrowableCol(1);
 	// Start/End
 	wxSizer* timeSizer = AddTextProp(grid, _("Subpicture start/end:"), m_menu->GetStartTime(), false, 100, false);
@@ -156,47 +192,9 @@ void MenuPropDlg::CreateButtonsGroup(wxSizer* sizer) {
 	EndGroup();
 }
 
-void MenuPropDlg::CreateVobGroup(wxSizer* sizer, bool loop) {
-	wxSizer* grpSizer = BeginGroup(sizer, _("Video object"));
-	wxFlexGridSizer* grid = new wxFlexGridSizer(2, 4, 16);
-	grid->AddGrowableCol(1);
-	
-	// audio file
-	wxString audioFile = m_vob->GetAudioFilenames().size() ? m_vob->GetAudioFilenames()[0] : wxT("");
-	wxString audio = wxThumbnails::GetAudioExtWildcard();
-	AddFileProp(grid, _("Audio:"), audioFile, wxFD_OPEN, wxT("..."),
-			_("Audio Files") + wxString::Format(wxT(" (%s)|%s|"), audio.c_str(), audio.c_str())
-			+ _("All Files") + wxString(wxT(" (*.*)|*.*")), AUDIO_CTRL_ID);
-	m_audioCtrlIdx = GetLastControlIndex();
-	// audio format
-	Stream* stream = audioFile.length() > 0 ? m_vob->GetStreams()[m_vob->GetStreams().size() - 1] : NULL;
-	int af = stream != NULL ? stream->GetAudioFormat() - 1 : afCOPY - 1;
-	wxArrayString formats = DVD::GetAudioFormatLabels(true);
-	wxSizer* formatSizer = AddChoiceProp(grid, _("Format:"), formats[af], formats, 0, false);
-	m_audioFormat = (wxChoice*) GetLastControl();
-	m_audioFormat->Enable(audioFile.length() > 0);
-	wxArrayString labels = DVD::GetAudioLanguageCodes();
-	if (m_langCodes->GetCount() < 1)
-		m_langCodes->Add(s_config.GetDefAudioLanguage());
-	formatSizer->AddSpacer(4);
-	AddChoiceProp(formatSizer, wxT(""), (*m_langCodes)[0], labels, 0, false);
-	// cells & actions
-	AddButton(grid, _("Cells:"), CELLS_BT_ID);
-	AddButton(grid, _("Actions:"), ACTIONS_BT_ID);
-	// pause and loop
-	wxSizer* pSizer = AddSpinProp(grid, _("Pause:"), m_vob->GetPause(), -1, 254, 100, _("sec"),false);
-	m_pauseCtrl = (wxSpinCtrl*) GetLastControl();
-	m_pauseCtrl->Enable(!loop);
-	pSizer->AddSpacer(4);
-	AddCheckProp(pSizer, _("Loop"), loop, false, LOOP_CB_ID);
-	
-	grpSizer->Add(grid, 0, wxEXPAND|wxALL, 4);
-	sizer->AddSpacer(6);
-}
-
 void MenuPropDlg::CreateMenuGroup(wxSizer* sizer, bool loop) {	
 	wxSizer* grpSizer = BeginGroup(sizer, _("Menu"));
-	wxFlexGridSizer* grid = new wxFlexGridSizer(2, 4, 16);
+	wxFlexGridSizer* grid = new wxFlexGridSizer(2, 4, 6);
 	grid->AddGrowableCol(1);
 	
 	const StringSet& entries = m_pgc->GetEntries();
@@ -223,6 +221,26 @@ void MenuPropDlg::CreateMenuGroup(wxSizer* sizer, bool loop) {
 	grpSizer->Add(grid, 0, wxEXPAND|wxALL, 4);
 }
 
+/**
+ * Creates panel with buttons
+ */
+void MenuPropDlg::CreateButtonPane(wxSizer* sizer, bool resetButton, bool dontShowCheckbox) {
+	wxStdDialogButtonSizer* buttonPane = new wxStdDialogButtonSizer();
+	
+	// cells & actions buttons
+	buttonPane->Add(new wxButton(this, CELLS_BT_ID, _("Cells...")));
+	buttonPane->Add(new wxButton(this, ACTIONS_BT_ID, _("Actions...")));
+	buttonPane->Add(10, 10, 1, wxEXPAND);
+	
+	// ok & cancel buttons
+	buttonPane->AddButton(new wxButton(this, wxID_OK, wxEmptyString));
+	buttonPane->AddButton(new wxButton(this, wxID_CANCEL, wxEmptyString));
+	
+	buttonPane->Realize();
+	buttonPane->GetAffirmativeButton()->SetDefault();
+	sizer->Add(buttonPane, 0, wxEXPAND|wxLEFT|wxRIGHT|wxBOTTOM, 10);
+}
+
 wxArrayString MenuPropDlg::GetCommands() {
 	wxArrayString commands;
 	commands.Add(wxT("jump cell 1;"));
@@ -310,12 +328,6 @@ bool MenuPropDlg::SetValues() {
 		n += 4;
 	m_menu->SetBackgroundColour(GetColour(n++));
 	
-	m_menu->SetStartTime(GetString(n++));
-	m_menu->SetEndTime(GetString(n++));
-	m_menu->SetRememberLastButton(GetBool(n++));
-	m_menu->SetRememberLastButtonRegister(m_menu->GetRememberLastButton() ? GetInt(n) - 1 : -1);
-	n++;
-	
 	// VOB properties
 	audioFile = GetString(n++).Strip(wxString::both);
 	while (m_vob->GetAudioFilenames().GetCount() > 0)
@@ -334,7 +346,14 @@ bool MenuPropDlg::SetValues() {
 	m_vob->GetCells().swap(m_cells);
 	m_menu->GetActions().swap(m_actions);
 	m_vob->SetPause(GetInt(n++));
-	n++;
+	n++; // loop
+	
+	// subpictures/buttons
+	m_menu->SetStartTime(GetString(n++));
+	m_menu->SetEndTime(GetString(n++));
+	m_menu->SetRememberLastButton(GetBool(n++));
+	m_menu->SetRememberLastButtonRegister(m_menu->GetRememberLastButton() ? GetInt(n) - 1 : -1);
+	n++; // Last button register
 	
 	// set entries
 	StringSet& entries = m_pgc->GetEntries();
