@@ -3,7 +3,7 @@
 // Purpose:     DVD menu properties dialog
 // Author:      Alex Thuering
 // Created:     25.04.2004
-// RCS-ID:      $Id: MenuPropDlg.h,v 1.12 2014/03/11 12:11:12 ntalex Exp $
+// RCS-ID:      $Id: MenuPropDlg.h,v 1.13 2014/09/20 05:54:03 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -24,7 +24,19 @@ public:
 	virtual ~MenuPropDlg();
 	
 protected:
+	/**
+	 * Creates properties panel.
+	 */
 	void CreatePropPanel(wxSizer* sizer);
+	
+	/**
+	 * Creates panel with buttons
+	 */
+	void CreateButtonPane(wxSizer* sizer, bool resetButton = false, bool dontShowCheckbox = false);
+	
+	/**
+	 * Populate values on the model.
+	 */
   	bool SetValues();
   	
 private:
@@ -46,7 +58,6 @@ private:
 	int m_subStartCtrlIdx;
 	int m_audioCtrlIdx;
 	int m_preCommandsCtrlIdx;
-	void CreateBackgroundGroup(wxSizer* sizer);
 	void CreateButtonsGroup(wxSizer* sizer);
 	void CreateVobGroup(wxSizer* sizer, bool loop);
 	void CreateMenuGroup(wxSizer* sizer, bool loop);
