@@ -3,7 +3,7 @@
 // Purpose:     Settings dialog
 // Author:      Alex Thuering
 // Created:     27.03.2004
-// RCS-ID:      $Id: SettingsDlg.cpp,v 1.71 2013/10/25 21:19:15 ntalex Exp $
+// RCS-ID:      $Id: SettingsDlg.cpp,v 1.78 2015/01/31 13:34:46 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -82,21 +82,14 @@ void SettingsDlg::CreatePropPanel(wxSizer* sizer) {
 	// fix size
 	wxControl* videoChoice = GetLastControl();
 	discCapacityChoice->SetMinSize(videoChoice->GetBestSize());
-	if (vfSizer)
-		vfSizer->AddSpacer(4);
+	AddSpacer(vfSizer, 4);
 	// aspect ratio
 	labels = DVD::GetAspectRatioLabels();
 	AddChoiceProp(vfSizer, wxT(""), labels[s_config.GetDefAspectRatio() - 1], labels);
-#if wxCHECK_VERSION(2,9,3)
-	if (vfSizer)
-		vfSizer->GetItem(vfSizer->GetItemCount()-1)->SetProportion(0);
-#endif
 	wxControl* aspectRatioChoice = GetLastControl();
-	if (vfSizer)
-		vfSizer->AddSpacer(4);
+	AddSpacer(vfSizer, 4);
 	AddCheckProp(vfSizer, _("Keep aspect ratio"), s_config.GetDefKeepAspectRatio(def));
-	if (vfSizer)
-		vfSizer->AddStretchSpacer(1);
+	AddStretchSpacer(vfSizer, 1);
 	
 	// audio format
 	AddText(interfaceGrid, _("Default audio format:"));
@@ -110,12 +103,16 @@ void SettingsDlg::CreatePropPanel(wxSizer* sizer) {
 	AddChoiceProp(afSizer, wxT(""), labels[af], labels);
 	// fix size
 	GetLastControl()->SetMinSize(videoChoice->GetBestSize());
-	if (afSizer)
-		afSizer->AddSpacer(4);
+	AddSpacer(afSizer, 4);
 	// default audio language
 	labels = DVD::GetAudioLanguageCodes();
-	AddChoiceProp(afSizer, wxT(""), s_config.GetDefAudioLanguage(), labels, 0);
+	AddChoiceProp(afSizer, wxT(""), s_config.GetDefAudioLanguage(), labels);
 	GetLastControl()->SetMinSize(aspectRatioChoice->GetBestSize());
+	AddSpacer(afSizer, 4);
+	AddCheckProp(afSizer, wxT("5.1"), s_config.GetDefAudio51(def));
+	AddSpacer(afSizer, 4);
+	AddCheckProp(afSizer, _("Normalize"), s_config.GetDefAudioNormalize(def));
+	AddStretchSpacer(afSizer, 1);
 	
 	// default chapter length
 	AddSpinProp(interfaceGrid, _("Default chapter length:"), s_config.GetDefChapterLength(def), 0, 999, 60, _("min"));
@@ -149,8 +146,7 @@ void SettingsDlg::CreatePropPanel(wxSizer* sizer) {
 	wxControl* defButtonChoice = GetLastControl();
 	if (postCommandChoice->GetBestSize().GetWidth() < defButtonChoice->GetBestSize().GetWidth())
 		postCommandChoice->SetMinSize(defButtonChoice->GetBestSize());
-	if (dbtSizer)
-		dbtSizer->AddSpacer(4);
+	AddSpacer(dbtSizer, 4);
 	AddCheckProp(dbtSizer, _("Accept invalid actions"), s_config.GetAcceptInvalidActions(def));
 	
 	// Slideshow
@@ -173,8 +169,7 @@ void SettingsDlg::CreatePropPanel(wxSizer* sizer) {
 		fbChoices[fbDir.IsEmpty() ? 0 : 1], wxArrayString(2, fbChoices), 0, false, FILE_BROWSER_CHOICE_ID);
 	if (GetLastControl()->GetBestSize().GetWidth() < defButtonChoice->GetBestSize().GetWidth())
 		GetLastControl()->SetMinSize(defButtonChoice->GetBestSize());
-	if (fbSizer)
-		fbSizer->AddSpacer(4);
+	AddSpacer(fbSizer, 4);
 	AddDirectoryProp(fbSizer, wxT(""), fbDir);
 	if (fbSizer) {
 		m_directoryEdit = (wxTextCtrl*) GetLastControl();
@@ -190,6 +185,15 @@ void SettingsDlg::CreatePropPanel(wxSizer* sizer) {
 	
 	// undo history size
 	AddSpinProp(interfaceGrid, _("Undo history size:"), s_config.GetUndoHistorySize(def), 0, 9999, 60);
+	AddText(interfaceGrid, _("Clear transcoding cache:"));
+	wxSizer* grpSizer = BeginGroup(interfaceGrid, wxT(""));
+	wxArrayString options;
+	options.Add(_("Prompt"));
+	options.Add(_("Yes"));
+	options.Add(_("No"));
+	AddRadioGroupProp(grpSizer, options, s_config.GetCacheClearPrompt(def));
+	AddStretchSpacer(grpSizer, 1);
+	EndGroup();
 	
 	// don't show fags
 	AddText(interfaceGrid, _("\"Don't show again\" flags:"));
@@ -221,31 +225,27 @@ void SettingsDlg::CreatePropPanel(wxSizer* sizer) {
 	// ----------------- Core Tab -------------------- //
 	wxSizer* menuSizer = AddSpinProp(coreGrid, _("Frame count of menu:"), s_config.GetMenuFrameCount(def), 1, 9999, 80,
 			wxT(""), false);
-	if (menuSizer)
-		menuSizer->AddSpacer(6);
+	AddSpacer(menuSizer, 4);
 	AddCheckProp(menuSizer, _("Draw buttons on background"), s_config.GetDrawButtonsOnBackground(def));
 	AddSpinProp(coreGrid, _("Menu video bitrate:"), s_config.GetMenuVideoBitrate(def), 1, 9999, 80, _("KBit/s"));
 	AddSpinProp(coreGrid, _("Slideshow video bitrate:"), s_config.GetSlideshowVideoBitrate(def), 1, 9999, 80, _("KBit/s"));
 	AddSpinProp(coreGrid, _("Default audio bitrate:"), s_config.GetAudioBitrate(def), 1, 9999, 80, _("KBit/s"));
 	AddSpinProp(coreGrid, _("Thread count:"), s_config.GetThreadCount(def), 1, 99, 80);
 	AddSpinProp(coreGrid, _("DVD reserved space:"), s_config.GetDvdReservedSpace(def), 0, 9999999, 80, _("KB"));
-#if defined(__WXMSW__)
-	AddFileProp(coreGrid, _("Preview command:"), s_config.GetPreviewCmd(def), wxFD_OPEN, wxT("..."),
-			wxString(_("Executable Files ")) + wxT(" (*.exe)|*.exe") + wxT("|") +
-			wxString(_("All Files")) + wxT(" (*.*)|*.*"));
-#else
-	AddTextProp(coreGrid, _("Preview command:"), s_config.GetPreviewCmd(def));
-#endif
 	AddTextProp(coreGrid, _("Create ISO command:"), s_config.GetIsoCmd(def));
 	AddTextProp(coreGrid, _("Burn command:"), s_config.GetBurnCmd(def));
 	AddTextProp(coreGrid, _("Burn ISO command:"), s_config.GetBurnISOCmd(def));
 	AddTextProp(coreGrid, _("Add ECC command:"), s_config.GetAddECCCmd(def));
 	AddTextProp(coreGrid, _("Format command:"), s_config.GetFormatCmd(def));
+	labels.clear();;
+	labels.Add(_("Yes"));
+	labels.Add(_("No"));
+	labels.Add(_("For menus only"));
+	int opt = s_config.GetUseMplex(def) ? 0 : (s_config.GetUseMplexForMenus(def) ? 2 : 1);
+	AddChoiceProp(coreGrid, _("Use mplex:"), labels[opt], labels, 0, false);
 
-	wxSizer* grpSizer = BeginGroup(debugSizer, _("Debug"));
+	grpSizer = BeginGroup(debugSizer, _("Debug"));
 	AddCheckProp(grpSizer, _("Don't remove temp files"), !s_config.GetRemoveTempFiles(def));
-	AddCheckProp(grpSizer, _("Use mplex"), s_config.GetUseMplex(def));
-	AddCheckProp(grpSizer, _("Use mplex for menus"), s_config.GetUseMplexForMenus(def));
 }
 
 bool SettingsDlg::SetValues() {
@@ -266,6 +266,8 @@ bool SettingsDlg::SetValues() {
 	s_config.SetDefKeepAspectRatio(GetBool(i++));
 	s_config.SetDefAudioFormat(GetInt(i++) + 2);
 	s_config.SetDefAudioLanguage(GetString(i++));
+	s_config.SetDefAudio51(GetBool(i++));
+	s_config.SetDefAudioNormalize(GetBool(i++));
 	s_config.SetDefChapterLength(GetInt(i++));
 	s_config.SetDefPostCommand(GetInt(i++));
 	s_config.SetDefButton(m_buttons[GetInt(i++)]);
@@ -280,6 +282,7 @@ bool SettingsDlg::SetValues() {
 	s_config.SetClearThumbnailCache(GetBool(i++));
 #endif
 	s_config.SetUndoHistorySize(GetInt(i++));
+	s_config.SetCacheClearPrompt(GetInt(i++));
 	
 	// system core settings
 	s_config.SetMenuFrameCount(GetInt(i++));
@@ -289,15 +292,15 @@ bool SettingsDlg::SetValues() {
 	s_config.SetAudioBitrate(GetInt(i++));
 	s_config.SetThreadCount(GetInt(i++));
 	s_config.SetDvdReservedSpace(GetInt(i++));
-	s_config.SetPreviewCmd(GetString(i++));
 	s_config.SetIsoCmd(GetString(i++));
 	s_config.SetBurnCmd(GetString(i++));
 	s_config.SetBurnISOCmd(GetString(i++));
 	s_config.SetAddECCCmd(GetString(i++));
 	s_config.SetFormatCmd(GetString(i++));
+	int mplex = GetInt(i++);
+	s_config.SetUseMplex(mplex == 0);
+	s_config.SetUseMplexForMenus(mplex == 0 || mplex == 2);
 	s_config.SetRemoveTempFiles(!GetBool(i++));
-	s_config.SetUseMplex(GetBool(i++));
-	s_config.SetUseMplexForMenus(GetBool(i++));
 	return true;
 }
 
@@ -312,6 +315,19 @@ void SettingsDlg::OnResetDontShowFlags(wxCommandEvent& evt) {
 	s_config.SetShowWelcomeDlg(true);
 	s_config.SetTitleDeletePrompt(true);
 	s_config.SetOverwriteOutputDirPrompt(true);
+	s_config.SetCacheClearPrompt(0);
 	wxMessageBox(_("All \"don't show again\" flags are reseted."), _("Settings"),
 			wxOK | wxCENTRE | wxICON_INFORMATION);
 }
+
+
+void SettingsDlg::AddSpacer(wxSizer* sizer, int size) {
+	if (sizer)
+		sizer->AddSpacer(size);
+}
+
+void SettingsDlg::AddStretchSpacer(wxSizer* sizer, int prop) {
+	if (sizer)
+		sizer->AddStretchSpacer(prop);
+	
+}
