@@ -3,7 +3,7 @@
 // Purpose:     DVD title properties dialog
 // Author:      Alex Thuering
 // Created:     31.01.2004
-// RCS-ID:      $Id: TitlePropDlg.cpp,v 1.60 2013/04/14 05:33:21 ntalex Exp $
+// RCS-ID:      $Id: TitlePropDlg.cpp,v 1.63 2013/12/29 21:41:13 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -13,6 +13,7 @@
 #include "MPEG.h"
 #include "Config.h"
 #include "ChaptersDlg.h"
+#include "SlideDlg.h"
 #include <wxVillaLib/utils.h>
 #include <wx/tokenzr.h>
 #include <wx/regex.h>
@@ -38,6 +39,7 @@ enum {
 BEGIN_EVENT_TABLE(TitlePropDlg, wxPropDlg)
 	EVT_LISTBOX(VOB_BOX_ID, TitlePropDlg::OnSelectItem)
 	EVT_THUMBNAILS_SEL_CHANGED(SLIDESHOW_BOX_ID, TitlePropDlg::OnSelectItem)
+	EVT_THUMBNAILS_DCLICK(SLIDESHOW_BOX_ID, TitlePropDlg::OnThumbDoubleClick)
 	EVT_BUTTON(ADD_BT_ID, TitlePropDlg::OnAddBt)
 	EVT_BUTTON(REMOVE_BT_ID, TitlePropDlg::OnRemoveBt)
 	EVT_BUTTON(PROP_BT_ID, TitlePropDlg::OnPropBt)
@@ -77,6 +79,8 @@ TitlePropDlg::TitlePropDlg(wxWindow* parent, DVD* dvd, int tsi, int pgci, int vo
 		m_vobListBox->SetSelection(0);
 	wxCommandEvent evt;
 	OnSelectItem(evt);
+	if (m_slideShowBox)
+		m_slideShowBox->SetFocus();
 }
 
 TitlePropDlg::~TitlePropDlg() {
@@ -87,7 +91,6 @@ TitlePropDlg::~TitlePropDlg() {
 void TitlePropDlg::CreatePropPanel(wxSizer* sizer) {
 	if (m_vob->GetSlideshow()) {
 		CreateSlideshowGroup(sizer);
-		CreateAudioGroup(sizer);
 	} else
 		CreateVobGroup(sizer);
 	CreateTitleGroup(sizer);
@@ -147,7 +150,7 @@ void TitlePropDlg::CreateSlideshowGroup(wxSizer* sizer) {
 	Slideshow* slideshow = m_vob->GetSlideshow();
 	wxSizer* grpSizer = BeginGroup(sizer, _("Slideshow"), wxT(""), false, false, true, 1);
 	wxBoxSizer* vobPane = new wxBoxSizer(wxHORIZONTAL);
-	vobPane->SetMinSize(590, 300);
+	vobPane->SetMinSize(646, 320);
 	grpSizer->Add(vobPane, 1, wxEXPAND);
 	
 	m_slideShowBox = new wxThumbnails(this, SLIDESHOW_BOX_ID);
@@ -167,6 +170,10 @@ void TitlePropDlg::CreateSlideshowGroup(wxSizer* sizer) {
 	m_delBt = new wxBitmapButton(this, REMOVE_BT_ID, wxBITMAP_FROM_MEMORY(remove));
 	m_delBt->SetHelpText(_("Remove image"));
 	buttonPane->Add(m_delBt, 0, wxALIGN_CENTER);
+	buttonPane->Add(4, 4);
+	m_propBt = new wxBitmapButton(this, PROP_BT_ID, wxBITMAP_FROM_MEMORY(preferences));
+	m_propBt->SetHelpText(_("Properties..."));
+	buttonPane->Add(m_propBt, 0, wxALIGN_CENTER);
 	buttonPane->Add(10, 10, 1, wxEXPAND);
 	
 	wxFlexGridSizer* grid = new wxFlexGridSizer(2, 4, 4);
@@ -178,7 +185,59 @@ void TitlePropDlg::CreateSlideshowGroup(wxSizer* sizer) {
 	formats = DVD::GetAspectRatioLabels();
 	int ar = slideshow->GetAspectRatio() >= 1 ? slideshow->GetAspectRatio() - 1 : 0;
 	AddChoiceProp(formatSizer, wxT(""), formats[ar], formats, GetCharWidth()*8);
-	AddSpinProp(grid, _("Duration:"), slideshow->GetDuration(), 1, 1000, GetCharWidth()*15, _("sec"));
+	AddSpinProp(grid, _("Duration:"), slideshow->GetDuration(), 1, 1000, GetCharWidth()*8, _("sec"));
+	
+	// transitions
+	wxArrayString labels;
+	Slideshow::GetTransitions(m_transitions, labels);
+	int sel = 0;
+	for (unsigned int i = 0; i < m_transitions.GetCount(); i++) {
+		if (m_transitions[i] == slideshow->GetTransition()) {
+			sel = i;
+		}
+	}
+	AddChoiceProp(grid, _("Transition:"), labels[sel], labels, 0, false);
+	wxSize minSize = GetLastControl()->GetBestSize();
+	minSize.SetWidth(GetCharWidth()*23 + 4);
+	GetLastControl()->SetMinSize(minSize);
+//	AddText(grid, _("Transition:"), wxALIGN_CENTER_HORIZONTAL);
+//	m_transitionBox = new wxThumbnails(this, SLIDESHOW_BOX_ID);
+//	m_transitionBox->SetThumbSize(70, 60, 8);
+//	m_transitionBox->EnableDragging(false);
+//	int sel = 0;
+//	for (unsigned int i = 0; i < m_transitions.GetCount(); i++) {
+//		if (m_transitions[i] == slideshow->GetTransition()) {
+//			sel = i;
+//		}
+//		wxImage img =  SlideDlg::getTransitionImage(m_transitions[i]);
+//		wxThumb* thumb = new wxThumb(img, labels[i],  m_transitions[i]);
+//		m_transitionBox->InsertItem(thumb);
+//	}
+//	
+//	if (m_transitionBox->GetItemCount() > 0)
+//		m_transitionBox->SetSelected(sel);
+//	m_transitionBox->Update();
+//	grid->Add(m_transitionBox, 0, wxEXPAND);
+	
+	// audio file
+	wxString audioFile = m_vob->GetAudioFilenames().size() ? m_vob->GetAudioFilenames()[0] : wxT("");
+	wxString audio = wxThumbnails::GetAudioExtWildcard();
+	wxSizer* audioSizer = AddFileProp(grid, _("Audio file:"), audioFile, wxFD_OPEN, wxT("..."),
+			_("Audio Files") + wxString::Format(wxT(" (%s)|%s|"), audio.c_str(), audio.c_str())
+			+ _("All Files") + wxString(wxT(" (*.*)|*.*")), AUDIO_CTRL_ID);
+	// audio format
+	Stream* stream = audioFile.length() > 0 ? m_vob->GetStreams()[m_vob->GetStreams().size() - 1] : NULL;
+	int af = stream != NULL ? stream->GetAudioFormat() - 1 : afCOPY - 1;
+	formats = DVD::GetAudioFormatLabels(true);
+	audioSizer->Add(AddChoiceProp(formats[af], formats));
+	m_audioFormat = (wxChoice*) GetLastControl();
+	m_audioFormat->Enable(audioFile.length() > 0);
+	labels = DVD::GetAudioLanguageCodes();
+	if (m_langCodes->GetCount() < 1)
+		m_langCodes->Add(s_config.GetDefAudioLanguage());
+	audioSizer->AddSpacer(4);
+	audioSizer->Add(AddChoiceProp((*m_langCodes)[0], labels));
+	
 	grpSizer->Add(grid, 0, wxEXPAND|wxALL, 6);
 	sizer->AddSpacer(6);
 }
@@ -187,24 +246,6 @@ void TitlePropDlg::CreateAudioGroup(wxSizer* sizer) {
 	wxSizer* grpSizer = BeginGroup(sizer, _("Audio"));
 	wxFlexGridSizer* grid = new wxFlexGridSizer(2, 4, 16);
 	grid->AddGrowableCol(1);
-	// audio file
-	wxString audioFile = m_vob->GetAudioFilenames().size() ? m_vob->GetAudioFilenames()[0] : wxT("");
-	wxString audio = wxThumbnails::GetAudioExtWildcard();
-	AddFileProp(grid, _("File:"), audioFile, wxFD_OPEN, wxT("..."),
-			_("Audio Files") + wxString::Format(wxT(" (%s)|%s|"), audio.c_str(), audio.c_str())
-			+ _("All Files") + wxString(wxT(" (*.*)|*.*")), AUDIO_CTRL_ID);
-	// audio format
-	Stream* stream = audioFile.length() > 0 ? m_vob->GetStreams()[m_vob->GetStreams().size() - 1] : NULL;
-	int af = stream != NULL ? stream->GetAudioFormat() - 1 : afCOPY - 1;
-	wxArrayString formats = DVD::GetAudioFormatLabels(true);
-	wxSizer* formatSizer = AddChoiceProp(grid, _("Format:"), formats[af], formats, 0, false);
-	m_audioFormat = (wxChoice*) GetLastControl();
-	m_audioFormat->Enable(audioFile.length() > 0);
-	wxArrayString labels = DVD::GetAudioLanguageCodes();
-	if (m_langCodes->GetCount() < 1)
-		m_langCodes->Add(s_config.GetDefAudioLanguage());
-	formatSizer->AddSpacer(4);
-	AddChoiceProp(formatSizer, wxT(""), (*m_langCodes)[0], labels, 0, false);
 	
 	grpSizer->Add(grid, 0, wxEXPAND|wxALL, 4);
 	sizer->AddSpacer(6);
@@ -265,7 +306,7 @@ wxArrayString TitlePropDlg::GetCommandList(DVD* dvd, int currentTsi) {
 bool TitlePropDlg::SetValues() {
 	// validate audio file
 	if (m_vob->GetSlideshow()) {
-		wxString audioFile = GetString(3);
+		wxString audioFile = GetString(4);
 		if (audioFile.length() > 0) {
 			if (!wxFile::Exists(audioFile)) {
 				wxLogError(_("File %s doesn't exist."), audioFile.c_str());
@@ -282,7 +323,7 @@ bool TitlePropDlg::SetValues() {
 	}
 	
 	// check commands
-	int n = m_vob->GetSlideshow() ? 7 : 4;
+	int n = m_vob->GetSlideshow() ? 8 : 4;
 	wxString preCommands = GetString(n++);
 	wxString postCommands = GetString(n++);
 	DVDAction action;
@@ -316,9 +357,7 @@ bool TitlePropDlg::SetValues() {
 		slideshow->SetAspectRatio((AspectRatio) (GetInt(n++)+1));
 		m_pgcs->GetVideo().SetAspect(slideshow->GetAspectRatio());
 		slideshow->SetDuration(GetInt(n++));
-		slideshow->Clear();
-		for (int i = 0; i < m_slideShowBox->GetItemCount(); i++)
-			slideshow->AddSlide(new Slide(m_slideShowBox->GetItem(i)->GetFilename()));
+		slideshow->SetTransition(m_transitions[GetInt(n++)]);
 		
 		// audio properties
 		wxString audioFile = GetString(n++).Strip(wxString::both);
@@ -365,6 +404,7 @@ bool TitlePropDlg::SetValues() {
 void TitlePropDlg::OnSelectItem(wxCommandEvent& event) {
 	if (m_slideShowBox) {
 		m_delBt->Enable(m_slideShowBox->GetSelectedCount() > 0);
+		m_propBt->Enable(m_slideShowBox->GetSelectedCount() > 0);
 	} else {
 		m_delBt->Enable(m_vobListBox->GetSelection() > 0);
 	}
@@ -379,8 +419,10 @@ void TitlePropDlg::OnAddBt(wxCommandEvent& event) {
 		if (fileDlg.ShowModal() == wxID_OK) {
 			wxArrayString paths;
 			fileDlg.GetPaths(paths);
-			for (unsigned int i = 0; i < paths.GetCount(); i++)
-			m_slideShowBox->InsertItem(new wxThumb(paths[i], paths[i].AfterLast(wxFILE_SEP_PATH)));
+			for (unsigned int i = 0; i < paths.GetCount(); i++) {
+				m_vob->GetSlideshow()->AddSlide(new Slide(paths[i]));
+				m_slideShowBox->InsertItem(new wxThumb(paths[i], paths[i].AfterLast(wxFILE_SEP_PATH)));
+			}
 		}
 		return;
 	}
@@ -411,8 +453,10 @@ void TitlePropDlg::OnRemoveBt(wxCommandEvent& event) {
 	if (m_slideShowBox != NULL) {
 		wxArrayInt selected = m_slideShowBox->GetSelectedArray();
 		selected.Sort(&cmpIntRev);
-		for (unsigned int i = 0; i < selected.GetCount(); i++)
+		for (unsigned int i = 0; i < selected.GetCount(); i++) {
+			m_vob->GetSlideshow()->RemoveSlide(selected[i]);
 			m_slideShowBox->RemoveItemAt(selected[i]);
+		}
 		m_slideShowBox->SetSelected(-1);
 		m_slideShowBox->Refresh();
 		return;
@@ -424,10 +468,22 @@ void TitlePropDlg::OnRemoveBt(wxCommandEvent& event) {
 }
 
 void TitlePropDlg::OnPropBt(wxCommandEvent& event) {
+	if (m_slideShowBox != NULL) {
+		SlideDlg slideDlg(this, m_vob->GetSlideshow()->GetSlide(m_slideShowBox->GetSelected()), GetInt(3));
+		slideDlg.ShowModal();
+		return;
+	}
 	m_vobListBox->ShowPropDialog();
 	UpdateDoNotTranscodeCheck();
 }
 
+void TitlePropDlg::OnThumbDoubleClick(wxCommandEvent& event) {
+	if (m_slideShowBox->GetSelected() >= 0) {
+		SlideDlg slideDlg(this, m_vob->GetSlideshow()->GetSlide(m_slideShowBox->GetSelected()), GetInt(3));
+		slideDlg.ShowModal();
+	}
+}
+
 void TitlePropDlg::OnDoNotTranscodeCheck(wxCommandEvent& event) {
 	m_vobListBox->SetDoNotTranscode(event.IsChecked());
 }
