@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD Titleset
 // Author:      Alex Thuering
 // Created:	    29.01.2003
-// RCS-ID:      $Id: Titleset.h,v 1.4 2012/06/10 20:47:10 ntalex Exp $
+// RCS-ID:      $Id: Titleset.h,v 1.6 2014/01/19 17:11:07 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -160,14 +160,14 @@ public:
 	StringSet GetEntries();
 	int GetPgciByEntry(wxString entry);
 	
-	wxSvgXmlNode* GetXML(DVDFileType type, DVD* dvd);
-	bool PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi);
+	wxSvgXmlNode* GetXML(DVDFileType type, DVD* dvd, bool vmgm = false);
+	bool PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi, wxProgressDialog* progressDlg);
 };
 
 class Titles: public PgcArray {
 public:
 	wxSvgXmlNode* GetXML(DVDFileType type, DVD* dvd, int nextTitleset);
-	bool PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi);
+	bool PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi, wxProgressDialog* progressDlg);
 };
 
 class Titleset {
@@ -180,7 +180,7 @@ public:
 	inline bool IsEmpty() { return GetMenus().Count() == 0 && GetTitles().Count() == 0; }
 	
 	wxSvgXmlNode* GetXML(DVDFileType type, DVD* dvd, int nextTitleset = -1);
-	bool PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi);
+	bool PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi, wxProgressDialog* progressDlg);
 	
 private:
 	Menus m_menus;
@@ -195,7 +195,7 @@ public:
     void SetFpc(wxString fpc) { m_fpc = fpc; }
 	
     wxSvgXmlNode* GetXML(DVDFileType type, DVD* dvd);
-	bool PutXML(wxSvgXmlNode* node, DVD* dvd);
+	bool PutXML(wxSvgXmlNode* node, DVD* dvd, wxProgressDialog* progressDlg);
 	
 private:
 	wxString m_fpc;
