@@ -3,7 +3,7 @@
 // Purpose:     Titleset Manager
 // Author:      Alex Thuering
 // Created:	27.01.2003
-// RCS-ID:      $Id: TitlesetManager.cpp,v 1.92 2014/03/31 08:37:09 ntalex Exp $
+// RCS-ID:      $Id: TitlesetManager.cpp,v 1.100 2015/01/31 16:10:01 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -16,6 +16,7 @@
 #include "Config.h"
 #include "Utils.h"
 #include "MessageDlg.h"
+#include "ProcessTranscode.h"
 #include <wxVillaLib/ThumbnailFactory.h>
 #include <wxVillaLib/ImageProc.h>
 #include <wxVillaLib/utils.h>
@@ -534,6 +535,7 @@ bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi,
 	if (pgcs.GetVideo().GetFormat() <= vfCOPY)
 		pgcs.GetVideo().SetFormat(m_dvd->GetVideoFormat());
 	// check if reencoding is needed
+	int audioStreamIdx = 0;
 	for (unsigned int i=0; i<vob->GetStreams().size(); i++) {
 		Stream* stream = vob->GetStreams()[i];
 		if (stream->GetType() == stVIDEO) {
@@ -542,6 +544,7 @@ bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi,
 					|| vob->GetStreams().size() == 1 // only video is available
 					|| !stream->GetSourceCodecName().StartsWith(wxT("mpeg2video"))
 					|| stream->GetSourceVideoFormat() != pgcs.GetVideo().GetFormat()
+					|| (s_config.GetDefRencodeNtscFilm() && lround(stream->GetSourceFps()) == 24)
 					|| fabs(stream->GetSourceAspectRatio()
 							- GetFrameAspectRatio(vfPAL, pgcs.GetVideo().GetAspect())) >= 0.15) {
 				stream->SetDestinationFormat(pgcs.GetVideo().GetFormat());
@@ -555,6 +558,18 @@ bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi,
 				stream->SetDestinationFormat(m_dvd->GetAudioFormat());
 				vob->SetDoNotTranscode(false);
 			}
+			if (s_config.GetDefAudio51() && m_dvd->GetAudioFormat() == afAC3
+					&& stream->GetSourceChannelNumber() != 6) {
+				stream->SetDestinationFormat(m_dvd->GetAudioFormat());
+				stream->SetChannelNumber(6);
+				vob->SetDoNotTranscode(false);
+			}
+			if (s_config.GetDefAudioNormalize() && m_dvd->GetAudioFormat() == afAC3) {
+				stream->SetDestinationFormat(m_dvd->GetAudioFormat());
+				vob->SetDoNotTranscode(false);
+				stream->SetAudioAdjustType(aatNormalize);
+			}
+			audioStreamIdx++;
 		} else if (stream->GetType() == stSUBTITLE) {
 			stream->SetDestinationFormat(stream->GetSourceCodecName() == wxT("dvdsub") ? sfCOPY : sfNONE);
 		}
@@ -567,7 +582,8 @@ bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi,
 		pgc->SetPostCommands(m_dvd->GetDefPostCommandStr());
 		pgc->GetVobs().Add(vob);
 		pgcs.Add(pgc);
-		if (allowMenuDuplication && !m_dvd->UpdateButtonImageFor(tsi, pgcs.GetCount() - 1) && pgcs.GetCount() > 4) {
+		m_dvd->UpdateButtonImageFor(tsi, pgcs.GetCount() - 1);
+		if (allowMenuDuplication && !m_dvd->HasButtonWithJumpAction(tsi, pgcs.GetCount() - 1) && pgcs.GetCount() > 4) {
 			// find menu to duplicate
 			bool found = false;
 			Menus& vmgmMenus = m_dvd->GetVmgm();
@@ -677,6 +693,17 @@ bool TitlesetManager::AddAudio(const wxString& fname) {
 		stream->SetDestinationFormat(m_dvd->GetAudioFormat());
 	else if (stream->GetSourceSampleRate() != 48000)
 		stream->SetDestinationFormat(stream->GetSourceAudioFormat());
+	if (s_config.GetDefAudio51() && m_dvd->GetAudioFormat() == afAC3
+			&& stream->GetSourceChannelNumber() != 6) {
+		stream->SetDestinationFormat(m_dvd->GetAudioFormat());
+		stream->SetChannelNumber(6);
+		vob->SetDoNotTranscode(false);
+	}
+	if (s_config.GetDefAudioNormalize() && m_dvd->GetAudioFormat() == afAC3) {
+		stream->SetDestinationFormat(m_dvd->GetAudioFormat());
+		vob->SetDoNotTranscode(false);
+		stream->SetAudioAdjustType(aatNormalize);
+	}
 	UpdateItems();
 	SendDvdChangedEvent();
 	return true;
@@ -692,7 +719,7 @@ bool TitlesetManager::AddSubtitles(const wxString& fname) {
 		return false;
 	}
 	Vob* vob = pgcs.Last()->GetVobs().Last();
-	vob->GetSubtitles().Add(new TextSub(fname));
+	vob->AddSubtitlesFile(fname);
 	UpdateItems();
 	SendDvdChangedEvent();
 	return true;
@@ -876,6 +903,9 @@ bool TitlesetManager::CreateChapterMenu(int targetTsi, int chapterCount) {
 	int chapter = 0;
 
 	// check if chapter menu already exists
+	if (targetTsi == 0 && m_dvd->GetTitlesets().size() == 0) {
+		m_dvd->AddTitleset();
+	}
 	Titleset* titleset = m_dvd->GetTitlesets()[targetTsi];
 	int pttMenu = titleset->GetMenus().GetPgciByEntry(wxT("ptt"));
 	if (pttMenu >= 0) {
