@@ -3,7 +3,7 @@
 // Purpose:     Miscellaneous utilities
 // Author:      Alex Thuering
 // Created:		06.04.2008
-// RCS-ID:      $Id: Utils.cpp,v 1.10 2013/03/12 06:54:06 ntalex Exp $
+// RCS-ID:      $Id: Utils.cpp,v 1.11 2014/09/20 05:49:46 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -136,3 +136,32 @@ long String2Time(const wxString& value, float fps) {
 	}
 	return result;
 }
+
+
+/**
+ * Converts color value in string
+ */
+wxString Colour2String(const wxColour& colour) {
+	if (!colour.IsOk()) {
+		return wxT("");
+	}
+	return colour.Alpha() != 255 ? wxString::Format(wxT("#%02x%02x%02x%02x"),
+			colour.Red(), colour.Green(), colour.Blue(), colour.Alpha()) :
+			wxString::Format(wxT("#%02x%02x%02x"), colour.Red(), colour.Green(), colour.Blue());
+}
+
+/**
+ * Converts string in color value
+ */
+wxColour String2Colour(const wxString& value) {
+	if (value.length() < 7 || value.GetChar(0) != wxT('#')) {
+		return wxColour();
+	}
+	long r = 0, g = 0, b = 0, a = 255;
+	value.Mid(1, 2).ToLong(&r, 16);
+	value.Mid(3, 2).ToLong(&g, 16);
+	value.Mid(5, 2).ToLong(&b, 16);
+	if (value.length() >= 9)
+		value.Mid(7, 2).ToLong(&a, 16);
+	return wxColour(r, g, b, a);
+}
