@@ -3,7 +3,7 @@
 // Purpose:     Miscellaneous utilities
 // Author:      Alex Thuering
 // Created:		06.04.2008
-// RCS-ID:      $Id: Utils.h,v 1.7 2013/03/11 10:29:40 ntalex Exp $
+// RCS-ID:      $Id: Utils.h,v 1.8 2014/09/20 05:49:46 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -14,6 +14,7 @@
 #include <wxSVGXML/svgxml.h>
 #include <wx/arrstr.h>
 #include <wx/regex.h>
+#include <wx/colour.h>
 #include <vector>
 
 using namespace std;
@@ -45,10 +46,12 @@ bool GetXmlFromClipboard(wxString dataFormatId, wxSvgXmlDocument& doc);
  * Gets text from clipboard.
  */
 wxString GetTextFromClipboard();
+
 /**
  * Sorts string arrays by value
  */
 int Sort(wxArrayString& keys, wxArrayString& values, const wxString& selectedKey = wxEmptyString);
+
 /**
  * Converts time span value (milliseconds) in string
  */
@@ -58,6 +61,15 @@ wxString Time2String(long value, bool full = false);
  */
 long String2Time(const wxString& value, float fps = 25);
 
+/**
+ * Converts color value in string
+ */
+wxString Colour2String(const wxColour& colour);
+/**
+ * Converts string in color value
+ */
+wxColour String2Colour(const wxString& value);
+
 /** Regular expression for time values */
 extern wxRegEx s_timeRE;
 
