@@ -3,7 +3,7 @@
 // Purpose:     The video properties dialog
 // Author:      Alex Thuering
 // Created:     09.09.2010
-// RCS-ID:      $Id: VideoPropDlg.cpp,v 1.21 2014/02/08 11:00:53 ntalex Exp $
+// RCS-ID:      $Id: VideoPropDlg.cpp,v 1.22 2014/09/27 06:00:25 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -32,6 +32,7 @@ const long VideoPropDlg::ASPECT_CHOICE_ID = wxNewId();
 const long VideoPropDlg::INTERLACED_CHOICE_ID = wxNewId();
 const long VideoPropDlg::FF_CHOICE_ID = wxNewId();
 const long VideoPropDlg::KEEP_ASPECT_CB_ID = wxNewId();
+const long VideoPropDlg::KEEP_ASPECT_CHOICE_ID = wxNewId();
 const long VideoPropDlg::ID_SPINCTRL1 = wxNewId();
 const long VideoPropDlg::ID_SPINCTRL4 = wxNewId();
 const long VideoPropDlg::ID_SPINCTRL3 = wxNewId();
@@ -40,8 +41,6 @@ const long VideoPropDlg::ID_SPINCTRL5 = wxNewId();
 const long VideoPropDlg::ID_SPINCTRL6 = wxNewId();
 const long VideoPropDlg::ID_SPINCTRL7 = wxNewId();
 const long VideoPropDlg::ID_SPINCTRL8 = wxNewId();
-const long VideoPropDlg::ID_STATICTEXT1 = wxNewId();
-const long VideoPropDlg::ID_STATICTEXT5 = wxNewId();
 const long VideoPropDlg::ID_SPINCTRL9 = wxNewId();
 const long VideoPropDlg::ID_SPINCTRL10 = wxNewId();
 const long VideoPropDlg::ID_TEXTCTRL1 = wxNewId();
@@ -71,26 +70,30 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
 	m_vob = vob;
 	m_stream = vob->GetVideoStream();
 	m_aspectRatio = aspectRatio;
+	m_videoPos = 0;
 
 	//(*Initialize(VideoPropDlg)
-	wxStaticText* StaticText9;
-	wxStaticText* staticText2;
-	wxGridBagSizer* GridBagSizer1;
+	wxGridBagSizer* gridBagSizer;
+	wxStaticText* srcLabel;
+	wxGridBagSizer* cropBagSizer;
+	wxBoxSizer* aspectSizer;
+	wxBoxSizer* fadeSizer;
 	wxStaticText* StaticText6;
-	wxBoxSizer* boxSizer1;
-	wxGridBagSizer* GridBagSizer2;
+	wxStaticText* filterLabel;
 	wxStaticText* StaticText8;
+	wxBoxSizer* padCropSizer;
+	wxStaticText* durLabel;
 	wxBoxSizer* mediaSizer;
-	wxStaticText* StaticText1;
-	wxStaticText* StaticText3;
 	wxStdDialogButtonSizer* stdDialogButtonSizer;
 	wxStaticText* staticText1;
-	wxStaticText* StaticText5;
-	wxStaticText* StaticText7;
+	wxStaticText* dstLabel;
 	wxGridBagSizer* borderSizer;
+	wxStaticText* startLabel;
 	wxBoxSizer* dstSizer;
-	wxBoxSizer* BoxSizer1;
-	wxBoxSizer* BoxSizer3;
+	wxStaticText* fadeLabel;
+	wxStaticText* endLabel;
+	wxBoxSizer* timeSizer;
+	wxStaticText* fileNameLabel;
 	wxBoxSizer* mainSizer;
 	wxBoxSizer* hSizer;
 
@@ -98,21 +101,21 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
 	SetClientSize(wxSize(1024,500));
 	mainSizer = new wxBoxSizer(wxVERTICAL);
 	hSizer = new wxBoxSizer(wxHORIZONTAL);
-	GridBagSizer1 = new wxGridBagSizer(2, 2);
-	StaticText1 = new wxStaticText(this, wxID_ANY, _("File Name:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
-	GridBagSizer1->Add(StaticText1, wxGBPosition(0, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	gridBagSizer = new wxGridBagSizer(2, 2);
+	fileNameLabel = new wxStaticText(this, wxID_ANY, _("File Name:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
+	gridBagSizer->Add(fileNameLabel, wxGBPosition(0, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
 	m_fileNameText = new wxStaticText(this, ID_STATICTEXT2, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT2"));
-	GridBagSizer1->Add(m_fileNameText, wxGBPosition(0, 1), wxDefaultSpan, wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
-	StaticText3 = new wxStaticText(this, wxID_ANY, _("Duration:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
-	GridBagSizer1->Add(StaticText3, wxGBPosition(1, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	gridBagSizer->Add(m_fileNameText, wxGBPosition(0, 1), wxDefaultSpan, wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	durLabel = new wxStaticText(this, wxID_ANY, _("Duration:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
+	gridBagSizer->Add(durLabel, wxGBPosition(1, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
 	m_durText = new wxStaticText(this, ID_STATICTEXT4, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT4"));
-	GridBagSizer1->Add(m_durText, wxGBPosition(1, 1), wxDefaultSpan, wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
-	StaticText5 = new wxStaticText(this, wxID_ANY, _("Source Format:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
-	GridBagSizer1->Add(StaticText5, wxGBPosition(2, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	gridBagSizer->Add(m_durText, wxGBPosition(1, 1), wxDefaultSpan, wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	srcLabel = new wxStaticText(this, wxID_ANY, _("Source Format:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
+	gridBagSizer->Add(srcLabel, wxGBPosition(2, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
 	m_srcText = new wxStaticText(this, ID_STATICTEXT3, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT3"));
-	GridBagSizer1->Add(m_srcText, wxGBPosition(2, 1), wxDefaultSpan, wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
-	StaticText7 = new wxStaticText(this, wxID_ANY, _("Destination Format:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
-	GridBagSizer1->Add(StaticText7, wxGBPosition(3, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	gridBagSizer->Add(m_srcText, wxGBPosition(2, 1), wxDefaultSpan, wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	dstLabel = new wxStaticText(this, wxID_ANY, _("Destination Format:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
+	gridBagSizer->Add(dstLabel, wxGBPosition(3, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
 	dstSizer = new wxBoxSizer(wxHORIZONTAL);
 	m_dstChoice = new wxChoice(this, DST_CHOICE_ID, wxDefaultPosition, wxDefaultSize, 0, 0, 0, wxDefaultValidator, _T("DST_CHOICE_ID"));
 	dstSizer->Add(m_dstChoice, 0, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
@@ -127,11 +130,17 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
 	m_ffChoice->Append(_("BFF"));
 	m_ffChoice->Append(_("TFF"));
 	dstSizer->Add(m_ffChoice, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-	GridBagSizer1->Add(dstSizer, wxGBPosition(3, 1), wxDefaultSpan, wxALL|wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
+	gridBagSizer->Add(dstSizer, wxGBPosition(3, 1), wxDefaultSpan, wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	aspectSizer = new wxBoxSizer(wxHORIZONTAL);
 	m_keepAspectCtrl = new wxCheckBox(this, KEEP_ASPECT_CB_ID, _("Keep Aspect Ratio"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("KEEP_ASPECT_CB_ID"));
 	m_keepAspectCtrl->SetValue(false);
-	GridBagSizer1->Add(m_keepAspectCtrl, wxGBPosition(4, 0), wxGBSpan(1, 2), wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
-	BoxSizer1 = new wxBoxSizer(wxHORIZONTAL);
+	aspectSizer->Add(m_keepAspectCtrl, 0, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	m_keepAspectChoice = new wxChoice(this, KEEP_ASPECT_CHOICE_ID, wxDefaultPosition, wxDefaultSize, 0, 0, 0, wxDefaultValidator, _T("KEEP_ASPECT_CHOICE_ID"));
+	m_keepAspectChoice->SetSelection( m_keepAspectChoice->Append(_("border")) );
+	m_keepAspectChoice->Append(_("crop"));
+	aspectSizer->Add(m_keepAspectChoice, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	gridBagSizer->Add(aspectSizer, wxGBPosition(4, 0), wxGBSpan(1, 2), wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	padCropSizer = new wxBoxSizer(wxHORIZONTAL);
 	m_padBox = new wxStaticBoxSizer(wxHORIZONTAL, this, _("Border"));
 	borderSizer = new wxGridBagSizer(2, 2);
 	m_padTop = new wxSpinCtrl(this, ID_SPINCTRL1, _T("0"), wxDefaultPosition, wxSize(58,-1), 0, 0, 999, 0, _T("ID_SPINCTRL1"));
@@ -147,43 +156,43 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
 	m_padLeft->SetValue(_T("0"));
 	borderSizer->Add(m_padLeft, wxGBPosition(1, 0), wxDefaultSpan, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
 	m_padBox->Add(borderSizer, 0, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
-	BoxSizer1->Add(m_padBox, 0, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	padCropSizer->Add(m_padBox, 0, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	m_cropBox = new wxStaticBoxSizer(wxHORIZONTAL, this, _("Crop"));
-	GridBagSizer2 = new wxGridBagSizer(2, 2);
+	cropBagSizer = new wxGridBagSizer(2, 2);
 	m_cropTop = new wxSpinCtrl(this, ID_SPINCTRL5, _T("0"), wxDefaultPosition, wxSize(58,-1), 0, 0, 999, 0, _T("ID_SPINCTRL5"));
 	m_cropTop->SetValue(_T("0"));
-	GridBagSizer2->Add(m_cropTop, wxGBPosition(0, 1), wxDefaultSpan, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
+	cropBagSizer->Add(m_cropTop, wxGBPosition(0, 1), wxDefaultSpan, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
 	m_cropBottom = new wxSpinCtrl(this, ID_SPINCTRL6, _T("0"), wxDefaultPosition, wxSize(58,-1), 0, 0, 999, 0, _T("ID_SPINCTRL6"));
 	m_cropBottom->SetValue(_T("0"));
-	GridBagSizer2->Add(m_cropBottom, wxGBPosition(2, 1), wxDefaultSpan, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
+	cropBagSizer->Add(m_cropBottom, wxGBPosition(2, 1), wxDefaultSpan, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
 	m_cropRight = new wxSpinCtrl(this, ID_SPINCTRL7, _T("0"), wxDefaultPosition, wxSize(58,-1), 0, 0, 999, 0, _T("ID_SPINCTRL7"));
 	m_cropRight->SetValue(_T("0"));
-	GridBagSizer2->Add(m_cropRight, wxGBPosition(1, 2), wxDefaultSpan, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
+	cropBagSizer->Add(m_cropRight, wxGBPosition(1, 2), wxDefaultSpan, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
 	m_cropLeft = new wxSpinCtrl(this, ID_SPINCTRL8, _T("0"), wxDefaultPosition, wxSize(58,-1), 0, 0, 999, 0, _T("ID_SPINCTRL8"));
 	m_cropLeft->SetValue(_T("0"));
-	GridBagSizer2->Add(m_cropLeft, wxGBPosition(1, 0), wxDefaultSpan, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
-	m_cropBox->Add(GridBagSizer2, 1, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
-	BoxSizer1->Add(m_cropBox, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-	GridBagSizer1->Add(BoxSizer1, wxGBPosition(5, 0), wxGBSpan(1, 2), wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
-	StaticText2 = new wxStaticText(this, ID_STATICTEXT1, _("Fade-In/Out:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT1"));
-	GridBagSizer1->Add(StaticText2, wxGBPosition(6, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
-	StaticText4 = new wxStaticText(this, ID_STATICTEXT5, _("Filters:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT5"));
-	GridBagSizer1->Add(StaticText4, wxGBPosition(7, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
-	BoxSizer3 = new wxBoxSizer(wxHORIZONTAL);
+	cropBagSizer->Add(m_cropLeft, wxGBPosition(1, 0), wxDefaultSpan, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
+	m_cropBox->Add(cropBagSizer, 1, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
+	padCropSizer->Add(m_cropBox, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	gridBagSizer->Add(padCropSizer, wxGBPosition(5, 0), wxGBSpan(1, 2), wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	fadeLabel = new wxStaticText(this, wxID_ANY, _("Fade-In/Out:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
+	gridBagSizer->Add(fadeLabel, wxGBPosition(6, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	filterLabel = new wxStaticText(this, wxID_ANY, _("Filters:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
+	gridBagSizer->Add(filterLabel, wxGBPosition(7, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	fadeSizer = new wxBoxSizer(wxHORIZONTAL);
 	m_fadeInCtrl = new wxSpinCtrl(this, ID_SPINCTRL9, _T("0"), wxDefaultPosition, wxSize(58,-1), 0, 0, 999, 0, _T("ID_SPINCTRL9"));
 	m_fadeInCtrl->SetValue(_T("0"));
-	BoxSizer3->Add(m_fadeInCtrl, 0, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
+	fadeSizer->Add(m_fadeInCtrl, 0, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
 	StaticText6 = new wxStaticText(this, wxID_ANY, _("sec"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
-	BoxSizer3->Add(StaticText6, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
+	fadeSizer->Add(StaticText6, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
 	m_fadeOutCtrl = new wxSpinCtrl(this, ID_SPINCTRL10, _T("0"), wxDefaultPosition, wxSize(58,-1), 0, 0, 999, 0, _T("ID_SPINCTRL10"));
 	m_fadeOutCtrl->SetValue(_T("0"));
-	BoxSizer3->Add(m_fadeOutCtrl, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	fadeSizer->Add(m_fadeOutCtrl, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	StaticText8 = new wxStaticText(this, wxID_ANY, _("sec"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
-	BoxSizer3->Add(StaticText8, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
-	GridBagSizer1->Add(BoxSizer3, wxGBPosition(6, 1), wxDefaultSpan, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	fadeSizer->Add(StaticText8, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
+	gridBagSizer->Add(fadeSizer, wxGBPosition(6, 1), wxDefaultSpan, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	m_filtersCtrl = new wxTextCtrl(this, ID_TEXTCTRL1, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL1"));
-	GridBagSizer1->Add(m_filtersCtrl, wxGBPosition(7, 1), wxDefaultSpan, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-	hSizer->Add(GridBagSizer1, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	gridBagSizer->Add(m_filtersCtrl, wxGBPosition(7, 1), wxDefaultSpan, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	hSizer->Add(gridBagSizer, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	mediaSizer = new wxBoxSizer(wxVERTICAL);
 	m_mediaCtrl = new MediaCtrlFF(this, ID_CUSTOM1, wxT(""), wxDefaultPosition,wxDefaultSize, 0, wxDefaultValidator, _T("ID_CUSTOM1"));
 	m_mediaCtrl->SetMinSize(wxSize(300, 200));
@@ -191,52 +200,52 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
 	mediaSizer->Add(m_mediaCtrl, 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 4);
 	m_slider = new wxSlider(this, ID_SLIDER, 0, 0, 100, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_SLIDER"));
 	mediaSizer->Add(m_slider, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
-	boxSizer1 = new wxBoxSizer(wxHORIZONTAL);
+	timeSizer = new wxBoxSizer(wxHORIZONTAL);
 	staticText1 = new wxStaticText(this, wxID_ANY, _("Time:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
-	boxSizer1->Add(staticText1, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 4);
+	timeSizer->Add(staticText1, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 4);
 	m_timeCtrl = new wxTextCtrl(this, ID_TIME_CTRL, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TIME_CTRL"));
-	boxSizer1->Add(m_timeCtrl, 0, wxLEFT|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
+	timeSizer->Add(m_timeCtrl, 0, wxLEFT|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
 	m_timeSpinBt = new wxSpinButton(this, ID_TIME_SPINB, wxDefaultPosition, wxDefaultSize, wxSP_VERTICAL|wxSP_ARROW_KEYS, _T("ID_TIME_SPINB"));
 	m_timeSpinBt->SetRange(0, 100);
 	m_timeSpinBt->SetMinSize(wxSize(16,12));
-	boxSizer1->Add(m_timeSpinBt, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	timeSizer->Add(m_timeSpinBt, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	m_frameSpinBt = new wxSpinButton(this, ID_FRAME_SPINBT, wxDefaultPosition, wxDefaultSize, wxSP_VERTICAL|wxSP_ARROW_KEYS|wxSP_WRAP, _T("ID_FRAME_SPINBT"));
 	m_frameSpinBt->SetRange(-9999, 9999);
 	m_frameSpinBt->SetMinSize(wxSize(16,12));
-	boxSizer1->Add(m_frameSpinBt, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-	staticText2 = new wxStaticText(this, wxID_ANY, _("Start:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
-	boxSizer1->Add(staticText2, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 8);
+	timeSizer->Add(m_frameSpinBt, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	startLabel = new wxStaticText(this, wxID_ANY, _("Start:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
+	timeSizer->Add(startLabel, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 8);
 	m_startCtrl = new wxTextCtrl(this, ID_TEXTCTRL2, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL2"));
-	boxSizer1->Add(m_startCtrl, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
+	timeSizer->Add(m_startCtrl, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
 	m_startSpin = new wxSpinButton(this, ID_SPINBUTTON1, wxDefaultPosition, wxDefaultSize, wxSP_VERTICAL|wxSP_ARROW_KEYS|wxSP_WRAP, _T("ID_SPINBUTTON1"));
 	m_startSpin->SetRange(-9999, 9999);
 	m_startSpin->SetMinSize(wxSize(16,12));
-	boxSizer1->Add(m_startSpin, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	timeSizer->Add(m_startSpin, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	m_startFrameSpin = new wxSpinButton(this, ID_SPINBUTTON2, wxDefaultPosition, wxDefaultSize, wxSP_VERTICAL|wxSP_ARROW_KEYS|wxSP_WRAP, _T("ID_SPINBUTTON2"));
 	m_startFrameSpin->SetRange(-9999, 9999);
 	m_startFrameSpin->SetMinSize(wxSize(16,12));
-	boxSizer1->Add(m_startFrameSpin, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	timeSizer->Add(m_startFrameSpin, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	m_startBt = new wxBitmapButton(this, START_BT_ID, wxArtProvider::GetBitmap(wxART_MAKE_ART_ID_FROM_STR(_T("wxART_CUT")),wxART_MENU), wxDefaultPosition, wxDefaultSize, wxBU_AUTODRAW, wxDefaultValidator, _T("START_BT_ID"));
 	m_startBt->SetDefault();
 	m_startBt->SetToolTip(_("Cut beginning"));
-	boxSizer1->Add(m_startBt, 0, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
-	StaticText9 = new wxStaticText(this, wxID_ANY, _("End:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
-	boxSizer1->Add(StaticText9, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	timeSizer->Add(m_startBt, 0, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
+	endLabel = new wxStaticText(this, wxID_ANY, _("End:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
+	timeSizer->Add(endLabel, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	m_endCtrl = new wxTextCtrl(this, ID_TEXTCTRL3, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL3"));
-	boxSizer1->Add(m_endCtrl, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
+	timeSizer->Add(m_endCtrl, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
 	m_endSpin = new wxSpinButton(this, ID_SPINBUTTON3, wxDefaultPosition, wxDefaultSize, wxSP_VERTICAL|wxSP_ARROW_KEYS|wxSP_WRAP, _T("ID_SPINBUTTON3"));
 	m_endSpin->SetRange(-9999, 9999);
 	m_endSpin->SetMinSize(wxSize(16,12));
-	boxSizer1->Add(m_endSpin, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
+	timeSizer->Add(m_endSpin, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
 	m_endFrameSpin = new wxSpinButton(this, ID_SPINBUTTON4, wxDefaultPosition, wxDefaultSize, wxSP_VERTICAL|wxSP_ARROW_KEYS|wxSP_WRAP, _T("ID_SPINBUTTON4"));
 	m_endFrameSpin->SetRange(-9999, 9999);
 	m_endFrameSpin->SetMinSize(wxSize(16,12));
-	boxSizer1->Add(m_endFrameSpin, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
+	timeSizer->Add(m_endFrameSpin, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
 	m_endBt = new wxBitmapButton(this, ID_RESET_TIME_BT, wxArtProvider::GetBitmap(wxART_MAKE_ART_ID_FROM_STR(_T("wxART_CUT")),wxART_MENU), wxDefaultPosition, wxDefaultSize, wxBU_AUTODRAW, wxDefaultValidator, _T("ID_RESET_TIME_BT"));
 	m_endBt->SetDefault();
 	m_endBt->SetToolTip(_("Cut ending"));
-	boxSizer1->Add(m_endBt, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
-	mediaSizer->Add(boxSizer1, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	timeSizer->Add(m_endBt, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
+	mediaSizer->Add(timeSizer, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	hSizer->Add(mediaSizer, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	mainSizer->Add(hSizer, 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	stdDialogButtonSizer = new wxStdDialogButtonSizer();
@@ -253,6 +262,7 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
 	Connect(ASPECT_CHOICE_ID,wxEVT_COMMAND_CHOICE_SELECTED,(wxObjectEventFunction)&VideoPropDlg::OnChangeAspect);
 	Connect(INTERLACED_CHOICE_ID,wxEVT_COMMAND_CHOICE_SELECTED,(wxObjectEventFunction)&VideoPropDlg::OnInterlaced);
 	Connect(KEEP_ASPECT_CB_ID,wxEVT_COMMAND_CHECKBOX_CLICKED,(wxObjectEventFunction)&VideoPropDlg::OnChangeKeepAspect);
+	Connect(KEEP_ASPECT_CHOICE_ID,wxEVT_COMMAND_CHOICE_SELECTED,(wxObjectEventFunction)&VideoPropDlg::OnChangeKeepAspect);
 	Connect(ID_SPINCTRL1,wxEVT_COMMAND_SPINCTRL_UPDATED,(wxObjectEventFunction)&VideoPropDlg::OnChangeBorder);
 	Connect(ID_SPINCTRL4,wxEVT_COMMAND_SPINCTRL_UPDATED,(wxObjectEventFunction)&VideoPropDlg::OnChangeBorder);
 	Connect(ID_SPINCTRL3,wxEVT_COMMAND_SPINCTRL_UPDATED,(wxObjectEventFunction)&VideoPropDlg::OnChangeBorder);
@@ -305,6 +315,7 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
     m_interlacedChoice->SetSelection(m_vob->GetInterlaced() ? 1 : 0);
     m_ffChoice->SetSelection(((int)m_vob->GetFirstField()) + 1);
     m_keepAspectCtrl->SetValue(m_vob->GetKeepAspectRatio());
+    m_keepAspectChoice->SetSelection(m_vob->GetKeepAspectCrop() ? 1 : 0);
     m_lastFormat = GetVideoFormat();
 
     // border
@@ -406,6 +417,7 @@ int VideoPropDlg::ShowModal() {
 		m_vob->SetInterlaced(m_interlacedChoice->GetSelection() == 1);
 		m_vob->SetFirstField((FirstField) (m_ffChoice->GetSelection() - 1));
 		m_vob->SetKeepAspectRatio(m_keepAspectCtrl->GetValue());
+		m_vob->SetKeepAspectCrop(m_keepAspectChoice->GetSelection() == 1);
 		m_vob->SetFadeIn(m_fadeInCtrl->GetValue());
 		m_vob->SetFadeOut(m_fadeOutCtrl->GetValue());
 		m_vob->SetVideoFilters(m_filtersCtrl->GetValue());
@@ -417,15 +429,28 @@ int VideoPropDlg::ShowModal() {
 	return res;
 }
 
-void VideoPropDlg::UpdatePad() {
+void VideoPropDlg::UpdatePadCrop() {
 	if (m_keepAspectCtrl->GetValue()) {
-		int padx = 0;
-		int pady = 0;
-		if (m_vob->CalcPad(padx, pady, GetVideoFormat(), GetAspectRatio(), GetCrop())) {
-			m_padLeft->SetValue(padx);
-			m_padRight->SetValue(padx);
-			m_padTop->SetValue(pady);
-			m_padBottom->SetValue(pady);
+		if (m_keepAspectChoice->GetSelection() == 0) {
+			// set border
+			int padx = 0;
+			int pady = 0;
+			if (m_vob->CalcPad(padx, pady, GetVideoFormat(), GetAspectRatio(), GetCrop())) {
+				m_padLeft->SetValue(padx);
+				m_padRight->SetValue(padx);
+				m_padTop->SetValue(pady);
+				m_padBottom->SetValue(pady);
+			}
+		} else  {
+			// set crop
+			int cropx = 0;
+			int cropy = 0;
+			if (m_vob->CalcCrop(cropx, cropy, GetVideoFormat(), GetAspectRatio(), GetPad())) {
+				m_cropLeft->SetValue(cropx);
+				m_cropRight->SetValue(cropx);
+				m_cropTop->SetValue(cropy);
+				m_cropBottom->SetValue(cropy);
+			}
 		}
 	}
 	// update preview
@@ -433,6 +458,7 @@ void VideoPropDlg::UpdatePad() {
 }
 
 void VideoPropDlg::SeekVideo(long pos, bool updateTimeCtrl) {
+	m_videoPos = pos;
 	m_slider->SetValue(lround(pos / 1000));
 	m_timeSpinBt->SetValue(lround(pos / 1000));
 	m_mediaCtrl->Seek((wxFileOffset) pos);
@@ -526,6 +552,7 @@ void VideoPropDlg::OnChangeFormat(wxCommandEvent& event) {
 	bool enablePad = enable && !m_keepAspectCtrl->GetValue();
 	m_interlacedChoice->Enable(enable);
 	m_keepAspectCtrl->Enable(enable);
+	m_keepAspectChoice->Enable(enable && m_keepAspectCtrl->GetValue());
 	m_padLeft->Enable(enablePad);
 	m_padRight->Enable(enablePad);
 	m_padTop->Enable(enablePad);
@@ -539,7 +566,7 @@ void VideoPropDlg::OnChangeFormat(wxCommandEvent& event) {
 	m_filtersCtrl->Enable(enable);
 	wxCommandEvent evt;
 	OnInterlaced(evt);
-	UpdatePad();
+	UpdatePadCrop();
 }
 
 void VideoPropDlg::OnInterlaced(wxCommandEvent& event) {
@@ -549,44 +576,64 @@ void VideoPropDlg::OnInterlaced(wxCommandEvent& event) {
 }
 
 void VideoPropDlg::OnChangeAspect(wxCommandEvent& event) {
-	UpdatePad();
+	UpdatePadCrop();
 }
 
 void VideoPropDlg::OnChangeKeepAspect(wxCommandEvent& event) {
-	bool enable = !m_keepAspectCtrl->GetValue();
-	m_padLeft->Enable(enable);
-	m_padRight->Enable(enable);
-	m_padTop->Enable(enable);
-	m_padBottom->Enable(enable);
-	if (enable) {
-		m_padLeft->SetValue(0);
-		m_padRight->SetValue(0);
-		m_padTop->SetValue(0);
-		m_padBottom->SetValue(0);
+	m_keepAspectChoice->Enable(m_keepAspectCtrl->GetValue());
+	bool keepAspect = m_keepAspectCtrl->GetValue();
+	bool border = m_keepAspectChoice->GetSelection() == 0;
+	m_padLeft->Enable(!keepAspect || !border);
+	m_padRight->Enable(!keepAspect || !border);
+	m_padTop->Enable(!keepAspect || !border);
+	m_padBottom->Enable(!keepAspect || !border);
+	m_cropLeft->Enable(!keepAspect || border);
+	m_cropRight->Enable(!keepAspect || border);
+	m_cropTop->Enable(!keepAspect || border);
+	m_cropBottom->Enable(!keepAspect || border);
+	if (keepAspect) {
+		if (border) {
+			m_cropLeft->SetValue(0);
+			m_cropRight->SetValue(0);
+			m_cropTop->SetValue(0);
+			m_cropBottom->SetValue(0);
+		} else {
+			m_padLeft->SetValue(0);
+			m_padRight->SetValue(0);
+			m_padTop->SetValue(0);
+			m_padBottom->SetValue(0);
+		}
+	} else {
+		if (border) {
+			m_padLeft->SetValue(0);
+			m_padRight->SetValue(0);
+			m_padTop->SetValue(0);
+			m_padBottom->SetValue(0);
+		} else {
+			m_cropLeft->SetValue(0);
+			m_cropRight->SetValue(0);
+			m_cropTop->SetValue(0);
+			m_cropBottom->SetValue(0);
+		}
 	}
-	UpdatePad();
+	UpdatePadCrop();
 }
 
 void VideoPropDlg::OnChangeBorder(wxSpinEvent& event) {
-	// update preview
-	m_mediaCtrl->SetVideoFormat(GetVideoFormat(), GetAspectRatio(), GetPad(), GetCrop());
+	UpdatePadCrop();
 }
 
 void VideoPropDlg::OnChangeCrop(wxSpinEvent& event) {
-	UpdatePad();
+	UpdatePadCrop();
 }
 
 void VideoPropDlg::OnStartBt(wxCommandEvent& event) {
-	int ms = m_slider->GetValue() != 0 ? m_mediaCtrl->Tell() % 1000 : 0;
-	int t = m_mediaCtrl->Tell() / 1000;
-	m_startCtrl->SetValue(wxString::Format(wxT("%d:%02d:%02d.%03d"), t/3600, (t/60) % 60, t%60, ms));
+	m_startCtrl->SetValue(Time2String(m_videoPos, true));
 }
 
 void VideoPropDlg::OnEndBt(wxCommandEvent& event) {
 	if (m_slider->GetValue() < m_slider->GetMax()) {
-		int ms = m_mediaCtrl->Tell() % 1000;
-		int t = m_mediaCtrl->Tell() / 1000;
-		m_endCtrl->SetValue(wxString::Format(wxT("%d:%02d:%02d.%03d"), t/3600, (t/60) % 60, t%60, ms));
+		m_endCtrl->SetValue(Time2String(m_videoPos, true));
 	} else
 		m_endCtrl->SetValue(wxT(""));
 }
