@@ -3,7 +3,7 @@
 // Purpose:     The class to store a VOB data
 // Author:      Alex Thuering
 // Created:     29.01.2003
-// RCS-ID:      $Id: Vob.cpp,v 1.1 2014/01/07 13:29:11 ntalex Exp $
+// RCS-ID:      $Id: Vob.cpp,v 1.7 2015/01/06 09:48:36 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -17,6 +17,7 @@
 #include <wx/filename.h>
 #include <wx/tokenzr.h>
 #include <wx/sstream.h>
+#include <wx/convauto.h>
 #include <wx/progdlg.h>
 #include <wxSVGXML/svgxmlhelpr.h>
 #include <wxVillaLib/utils.h>
@@ -57,6 +58,7 @@ void Vob::Init(Menu* menu, Slideshow* slideshow) {
 	m_interlaced = false;
 	m_firstField = ffAUTO;
 	m_keepAspectRatio = true;
+	m_keepAspectCrop = false;
 	for (int i = 0; i < 4; i++) {
 		m_pad.push_back(0);
 		m_crop.push_back(0);
@@ -84,6 +86,7 @@ Vob::Vob(const Vob& vob): m_pad(vob.m_pad), m_crop(vob.m_crop) {
 	m_interlaced = vob.m_interlaced;
 	m_firstField = vob.m_firstField;
 	m_keepAspectRatio = vob.m_keepAspectRatio;
+	m_keepAspectCrop = vob.m_keepAspectCrop;
 	m_doNotTranscode = vob.m_doNotTranscode;
 	m_fadeIn = vob.m_fadeIn;
 	m_fadeOut = vob.m_fadeOut;
@@ -144,9 +147,11 @@ bool Vob::HasAudio() {
 /** Returns count of audio streams */
 unsigned int Vob::GetAudioStreamCount() {
 	unsigned int cnt = 0;
-	for (vector<Stream*>::iterator it = m_streams.begin(); it != m_streams.end(); it++)
-		if ((*it)->GetType() == stAUDIO)
+	for (vector<Stream*>::iterator it = m_streams.begin(); it != m_streams.end(); it++) {
+		Stream* st = *it;
+		if (st->GetType() == stAUDIO && st->GetAudioFormat() != afNONE)
 			cnt++;
+	}
 	return cnt;
 }
 
@@ -154,9 +159,11 @@ unsigned int Vob::GetAudioStreamCount() {
 unsigned int Vob::GetSubtitleStreamsCount() {
 	unsigned int cnt = 0;
 	if (!m_menu) {
-		for (vector<Stream*>::iterator it = m_streams.begin(); it != m_streams.end(); it++)
-			if ((*it)->GetType() == stSUBTITLE)
+		for (vector<Stream*>::iterator it = m_streams.begin(); it != m_streams.end(); it++) {
+			Stream* st = *it;
+			if (st->GetType() == stSUBTITLE && st->GetSubtitleFormat() != sfNONE)
 				cnt++;
+		}
 		cnt += GetSubtitles().size();
 	} else
 		cnt = 1;
@@ -192,6 +199,41 @@ bool Vob::AddAudioFile(wxString filename) {
 	return true;
 }
 
+/** Adds the given subtitles file to the vob */
+bool Vob::AddSubtitlesFile(wxString filename) {
+	TextSub* textSub = new TextSub(filename);
+#if wxCHECK_VERSION(2,9,0)
+	// detect encoding
+	wxFile file;
+	if (!file.Open(filename))
+		return false;
+	char buf[1024];
+	int size = file.Read(buf, 1024);
+	wxBOM bom = wxConvAuto::DetectBOM(buf, size);
+	if (bom == wxBOM_UTF8) {
+		textSub->SetCharacterSet(wxT("UTF-8"));
+	} else if (bom == wxBOM_UTF16BE) {
+		textSub->SetCharacterSet(wxT("UTF-16BE"));
+	} else if (bom == wxBOM_UTF16LE) {
+		textSub->SetCharacterSet(wxT("UTF-16LE"));
+	} else if (bom == wxBOM_UTF32BE) {
+		textSub->SetCharacterSet(wxT("UTF-32BE"));
+	} else if (bom == wxBOM_UTF32LE) {
+		textSub->SetCharacterSet(wxT("UTF-32LE"));
+	} else if (!s_config.GetSubtitlesCharacterSet().StartsWith(wxT("UTF"))) {
+		textSub->SetCharacterSet(s_config.GetSubtitlesCharacterSet());
+	} else {
+		wxString encoding = wxLocale::GetSystemEncodingName();
+		if (encoding.StartsWith(wxT("windows-"))) {
+			encoding = wxT("CP") + encoding.substr(8);
+		}
+		textSub->SetCharacterSet(encoding);
+	}
+#endif
+	m_subtitles.Add(textSub);
+	return true;
+}
+
 /** Returns name of file to display */
 wxString Vob::GetFilenameDisplay() {
 	if (m_filename.StartsWith(wxT("concat:"))) {
@@ -246,15 +288,26 @@ int Vob::GetChapterCount() {
 	return result;
 }
 
-/** Updates pad values to keep aspect ratio*/
-void Vob::UpdatePad(AspectRatio aspectRatio) {
-	int padx = 0;
-	int pady = 0;
+/** Updates pad/crop values to keep aspect ratio*/
+void Vob::UpdatePadCrop(AspectRatio aspectRatio) {
 	Stream* videoSt = GetVideoStream();
 	VideoFormat videoFormat = videoSt != NULL ? videoSt->GetVideoFormat() : vfCOPY;
-	if (GetKeepAspectRatio() &&  CalcPad(padx, pady, videoFormat, aspectRatio, m_crop)) {
-		m_pad[0] = m_pad[1] = padx;
-		m_pad[2] = m_pad[3] = pady;
+	if (GetKeepAspectRatio()) {
+		if (GetKeepAspectCrop()) {
+			int cropx = 0;
+			int cropy = 0;
+			if (CalcCrop(cropx, cropy, videoFormat, aspectRatio, GetPad())) {
+				m_crop[0] = m_crop[1] = cropx;
+				m_crop[2] = m_crop[3] = cropy;
+			}
+		} else {
+			int padx = 0;
+			int pady = 0;
+			if (CalcPad(padx, pady, videoFormat, aspectRatio, GetCrop())) {
+				m_pad[0] = m_pad[1] = padx;
+				m_pad[2] = m_pad[3] = pady;
+			}
+		}
 	}
 }
 
@@ -271,7 +324,7 @@ bool Vob::CalcPad(int& padx, int& pady, VideoFormat videoFormat, AspectRatio asp
 		int cropX = crop[0] + crop[1];
 		int cropY = crop[2] + crop[3];
 		if (cropX + cropY > 0 && oldFrameSize.x > cropX && oldFrameSize.y > cropY)
-			oldAspect *= ((float) oldFrameSize.y)/oldFrameSize.x*(oldFrameSize.x - cropX)/(oldFrameSize.y - cropY);
+			oldAspect *= ((double) oldFrameSize.y)/oldFrameSize.x*(oldFrameSize.x - cropX)/(oldFrameSize.y - cropY);
 		float aspect = GetFrameAspectRatio(videoFormat, aspectRatio);
 		wxSize frameSize = GetFrameSize(videoFormat);
 		if (aspect > oldAspect)
@@ -282,6 +335,30 @@ bool Vob::CalcPad(int& padx, int& pady, VideoFormat videoFormat, AspectRatio asp
 	return true;
 }
 
+/** Calculates crop value to keep aspect ratio*/
+bool Vob::CalcCrop(int& cropx, int& cropy, VideoFormat videoFormat, AspectRatio aspectRatio, const vector<int>& pad) {
+	Stream* videoSt = GetVideoStream();
+	if (videoSt != NULL && videoSt->GetSourceAspectRatio() <= 0)
+		return false;
+	cropx = 0;
+	cropy = 0;
+	if (videoFormat != vfCOPY && aspectRatio != arAUTO) {
+		float oldAspect = videoSt->GetSourceAspectRatio();
+		wxSize oldFrameSize = videoSt->GetSourceVideoSize();
+		float aspect = GetFrameAspectRatio(videoFormat, aspectRatio);
+		wxSize frameSize = GetFrameSize(videoFormat);
+		int padX = pad[0] + pad[1];
+		int padY = pad[2] + pad[3];
+		if (padX + padY > 0 && frameSize.x > padX && frameSize.y > padY)
+			aspect *= ((double) frameSize.y)/frameSize.x*(frameSize.x - padX)/(frameSize.y - padY);
+		if (aspect > oldAspect)
+			cropy = lround(((double)oldFrameSize.y)*(1.0 - oldAspect/aspect)/2);
+		else if (aspect < oldAspect)
+			cropx = lround(((double)oldFrameSize.x)*(1.0 - aspect/oldAspect)/2);
+	}
+	return true;
+}
+
 /** Returns all video filters (incl. crop, pad, fade-in and fade-out) */
 wxString Vob::GetAllVideoFilters() {
 	wxString result;
@@ -344,6 +421,9 @@ wxString Vob::GetAllVideoFilters() {
 
 /** Returns duration of result video (sec) */
 double Vob::GetResultDuration() {
+	if (GetSlideshow()) {
+		return GetSlideshow()->GetResultDuration();
+	}
 	return GetRecordingTime() >= 0 ? GetRecordingTime() : GetDuration() - GetStartTime();
 }	
 
@@ -383,57 +463,13 @@ wxSvgXmlNode* Vob::GetXML(DVDFileType type, DVD* dvd) {
 	if (type == DVDSTYLER_XML) {
 		int stIdx = 0;
 		for (; stIdx < (int)(GetStreams().size() - GetAudioFilenames().size()); stIdx++) {
-			Stream* stream = GetStreams()[stIdx];
-			wxString streamName;
-			switch (stream->GetType()) {
-			case stVIDEO:
-				streamName = wxT("video");
-				break;
-			case stAUDIO:
-				streamName = wxT("audio");
-				break;
-			case stSUBTITLE:
-				streamName = wxT("subtitle");
-				break;
-			default:
-				break;
-			}
-			if (streamName.length() == 0)
+			if (GetStreams()[stIdx]->GetType() == stUNKNOWN)
 				continue;
-			wxSvgXmlNode* streamNode = new wxSvgXmlNode(wxSVGXML_ELEMENT_NODE, streamName);
-			streamNode->AddProperty(wxT("format"), wxString::Format(wxT("%d"), stream->GetDestinationFormat()));
-			if (stream->GetType() == stVIDEO) {
-				if (GetInterlaced()) {
-					streamNode->AddProperty(wxT("interlaced"), wxT("1"));
-					streamNode->AddProperty(wxT("firstField"), wxString::Format(wxT("%d"), GetFirstField()));
-				}
-				if (!GetKeepAspectRatio() && stream->GetVideoFormat() > vfCOPY)
-					streamNode->AddProperty(wxT("keepAspect"), wxT("0"));
-			} else if (stream->GetType() == stAUDIO) {
-				if (stream->GetAudioVolume() != 1.0)
-					streamNode->AddProperty(wxT("volume"), wxString::Format(wxT("%f"), stream->GetAudioVolume()));
-				if (stream->GetChannelNumber() != -1)
-					streamNode->AddProperty(wxT("channelNumber"), wxString::Format(wxT("%d"), stream->GetChannelNumber()));
-				if (stream->GetTsOffset() != 0)
-					streamNode->AddProperty(wxT("tsOffset"), wxString::Format(wxT("%ld"), stream->GetTsOffset()));
-				if (stream->GetFilters().length())
-					streamNode->AddProperty(wxT("filters"), stream->GetFilters());
-			}
-			node->AddChild(streamNode);
+			node->AddChild(GetStreams()[stIdx]->GetXML(type, this));
 		}
 		for (int i = 0; i < (int)GetAudioFilenames().size(); i++) {
-			Stream* stream = GetStreams()[stIdx++];
-			wxSvgXmlNode* audioNode = new wxSvgXmlNode(wxSVGXML_ELEMENT_NODE, wxT("audio"));
+			wxSvgXmlNode* audioNode = GetStreams()[stIdx++]->GetXML(type, this);
 			audioNode->AddChild(new wxSvgXmlNode(wxSVGXML_TEXT_NODE, wxEmptyString, GetAudioFilenames()[i]));
-			audioNode->AddProperty(wxT("format"), wxString::Format(wxT("%d"), stream->GetDestinationFormat()));
-			if (stream->GetAudioVolume() != 1.0)
-				audioNode->AddProperty(wxT("volume"), wxString::Format(wxT("%f"), stream->GetAudioVolume()));
-			if (stream->GetChannelNumber() != -1)
-				audioNode->AddProperty(wxT("channelNumber"), wxString::Format(wxT("%d"), stream->GetChannelNumber()));
-			if (stream->GetTsOffset() != 0)
-				audioNode->AddProperty(wxT("tsOffset"), wxString::Format(wxT("%ld"), stream->GetTsOffset()));
-			if (stream->GetFilters().length())
-				audioNode->AddProperty(wxT("filters"), stream->GetFilters());
 			node->AddChild(audioNode);
 		}
 		for (int i = 0;  i < (int) GetSubtitles().size(); i++) {
@@ -441,7 +477,7 @@ wxSvgXmlNode* Vob::GetXML(DVDFileType type, DVD* dvd) {
 		}
 		if (GetDoNotTranscode())
 			node->AddProperty(wxT("doNotTranscode"), wxT("1"));
-		if (!m_keepAspectRatio && m_pad[0] + m_pad[1] + m_pad[2] + m_pad[3] > 0) {
+		if (m_pad[0] + m_pad[1] + m_pad[2] + m_pad[3] > 0) {
 			wxSvgXmlNode* padNode = new wxSvgXmlNode(wxSVGXML_ELEMENT_NODE, wxT("pad"));
 			if (m_pad[0] > 0)
 				padNode->AddProperty(wxT("left"), wxString::Format(wxT("%d"), m_pad[0]));
@@ -572,19 +608,13 @@ bool Vob::PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi, int pgci, bool menu, boo
 					stIdx = 0;
 				while ((int)m_streams.size() > stIdx) {
 					if (m_streams[stIdx]->GetType() == stVIDEO) {
-						m_streams[stIdx++]->SetDestinationFormat(lval);
+						m_streams[stIdx]->PutXML(child, this);
+						stIdx++;
 						break;
 					}
 					stIdx++;
 				}
 			}
-			if (child->GetPropVal(wxT("interlaced"), &val) && val == wxT("1")) {
-				m_interlaced = true;
-				if (child->GetPropVal(wxT("firstField"), &val) && val.length() > 0 && val.ToLong(&lval))
-					m_firstField = (FirstField) lval;
-			}
-			if (child->GetPropVal(wxT("keepAspect"), &val) && val == wxT("0"))
-				m_keepAspectRatio = false;
 		} else if (child->GetName() == wxT("audio")) {
 			if (child->GetChildren() != NULL && child->GetChildren()->GetContent().length() > 0) {
 				val = child->GetChildren()->GetContent();
@@ -595,16 +625,7 @@ bool Vob::PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi, int pgci, bool menu, boo
 					val = dvd->GetPath() + fname.GetFullName();
 				if (AddAudioFile(val)) {
 					stIdx = m_streams.size() - 1;
-					if (child->GetPropVal(wxT("format"), &val) && val.length() > 0 && val.ToLong(&lval))
-						m_streams[stIdx]->SetDestinationFormat(lval);
-					if (child->GetPropVal(wxT("volume"), &val) && val.length() > 0 && val.ToDouble(&dval))
-						m_streams[stIdx]->SetAudioVolume(dval > 10 ? dval/256 : dval);
-					if (child->GetPropVal(wxT("channelNumber"), &val) && val.length() > 0 && val.ToLong(&lval))
-						m_streams[stIdx]->SetChannelNumber(lval);
-					if (child->GetPropVal(wxT("tsOffset"), &val) && val.length() > 0 && val.ToLong(&lval))
-						m_streams[stIdx]->SetTsOffset(lval);
-					if (child->GetPropVal(wxT("filters"), &val))
-						m_streams[stIdx]->SetFilters(val);
+					m_streams[stIdx]->PutXML(child, this);
 					stIdx++;
 				}
 			} else if (child->GetPropVal(wxT("format"), &val) && val.length() > 0 && val.ToLong(&lval)) {
@@ -612,13 +633,7 @@ bool Vob::PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi, int pgci, bool menu, boo
 					stIdx = 0;
 				while ((int)m_streams.size() > stIdx) {
 					if (m_streams[stIdx]->GetType() == stAUDIO) {
-						m_streams[stIdx]->SetDestinationFormat(lval);
-						if (child->GetPropVal(wxT("volume"), &val) && val.length() > 0 && val.ToDouble(&dval))
-							m_streams[stIdx]->SetAudioVolume(dval > 10 ? dval/256 : dval);
-						if (child->GetPropVal(wxT("channelNumber"), &val) && val.length() > 0 && val.ToLong(&lval))
-							m_streams[stIdx]->SetChannelNumber(lval);
-						if (child->GetPropVal(wxT("filters"), &val))
-							m_streams[stIdx]->SetFilters(val);
+						m_streams[stIdx]->PutXML(child, this);
 						stIdx++;
 						break;
 					}
@@ -631,7 +646,7 @@ bool Vob::PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi, int pgci, bool menu, boo
 					stIdx = 0;
 				while ((int)m_streams.size() > stIdx) {
 					if (m_streams[stIdx]->GetType() == stSUBTITLE) {
-						m_streams[stIdx]->SetDestinationFormat(lval);
+						m_streams[stIdx]->PutXML(child, this);
 						stIdx++;
 						break;
 					}
@@ -731,7 +746,10 @@ int Vob::GetOutputFileSize(DVD* dvd, int fileIdx) {
 		double duration = GetMenu()->GetSVG()->GetDuration();
 		if (duration < 1)
 			duration = s_config.GetMenuFrameCount()/(GetMenu()->GetVideoFormat() == vfPAL ? 25 : 30);
-		size += (long)(duration*s_config.GetMenuVideoBitrate()/8/3);
+		long menuSize = (long) (duration*s_config.GetMenuVideoBitrate()/8/3);
+		if (menuSize < 100)
+			menuSize = 100;
+		size += menuSize;
 	} else if (GetSlideshow()) {
 		size += GetSlideshow()->GetResultDuration()*s_config.GetSlideshowVideoBitrate()/8/3;
 	} else {
