@@ -3,7 +3,7 @@
 // Purpose:     Displays video
 // Author:      Alex Thuering
 // Created:     21.01.2011
-// RCS-ID:      $Id: mediactrl_ffmpeg.cpp,v 1.10 2013/05/26 18:34:24 ntalex Exp $
+// RCS-ID:      $Id: mediactrl_ffmpeg.cpp,v 1.11 2014/09/23 05:16:15 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -27,6 +27,10 @@ public:
 		// nothing to do
 	}
 
+	inline wxImage GetImage() {
+		return m_image;
+	}
+
 	inline void SetImage(wxImage image) {
 		m_image = image;
 		m_bitmap = wxBitmap();
@@ -162,7 +166,13 @@ public:
 		if (!m_loaded)
 			return false;
 		double dpos = where.ToDouble()/1000;
-		m_decoder.SetPosition(dpos > 1.0 ? dpos - 1.0 : 0.0);
+		if (dpos == 0 && m_decoder.GetPosition() != 0) {
+			m_decoder.SetPosition(0, false);
+			for (int i = 0; i < 8; i++) {
+				m_decoder.GetNextFrame();
+			}
+		}
+		m_decoder.SetPosition(dpos > 1.0 ? dpos - 1.0 : 0.0, dpos != 0);
 		wxImage image;
 		for (int i = 0; i < 60; i++) {
 			image = m_decoder.GetNextFrame();
@@ -191,10 +201,18 @@ public:
 		m_evtHandler->SetVideoFormat(videoFormat, aspectRatio, pad, crop);
 	}
 	
-	double GetFps() {
+	inline double GetFps() {
 		return m_decoder.GetFps();
 	}
 	
+	inline wxFfmpegMediaDecoder& GetDecoder() {
+		return m_decoder;
+	}
+
+	inline wxImage GetImage() {
+		return m_evtHandler->GetImage();
+	}
+	
 private:
 	bool m_loaded;
 	wxFfmpegMediaDecoder m_decoder;
@@ -233,3 +251,11 @@ void MediaCtrlFF::SetVideoFormat(VideoFormat videoFormat, AspectRatio aspectRati
 double MediaCtrlFF::GetFps() {
 	return ((wxFFMediaBackend*) m_imp)->GetFps();
 }
+
+wxFfmpegMediaDecoder& MediaCtrlFF::GetDecoder() {
+	return ((wxFFMediaBackend*) m_imp)->GetDecoder();
+}
+
+wxImage MediaCtrlFF::GetImage() {
+	return ((wxFFMediaBackend*) m_imp)->GetImage();
+}
