@@ -3,7 +3,7 @@
 // Purpose:     FFMPEG Media Transcoder
 // Author:      Alex Thuering
 // Created:     26.04.2008
-// RCS-ID:      $Id: mediatrc_ffmpeg.h,v 1.35 2014/03/31 08:36:22 ntalex Exp $
+// RCS-ID:      $Id: mediatrc_ffmpeg.h,v 1.38 2015/02/17 21:12:38 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -11,16 +11,22 @@
 #ifndef WX_FFMPEG_MEDIA_TRANSCODER_H
 #define WX_FFMPEG_MEDIA_TRANSCODER_H
 
-#include "mediatrc.h"
+#include "mediaenc.h"
+#include "wx/dynarray.h"
 #include <stdint.h>
 #include <math.h>
 #include <map>
+#include <vector>
 
-class wxFfmpegMediaTranscoder : public wxMediaTranscoder {
+using namespace std;
+
+class wxFfmpegMediaTranscoder {
 public:
-	wxFfmpegMediaTranscoder(int threadCount = 1);
+	wxFfmpegMediaTranscoder();
 	~wxFfmpegMediaTranscoder();
-	static void Init();
+	
+	/** Initializes transcoder command */
+	void Init();
 	
 	/** Adds input file. */
 	bool AddInputFile(const wxString& fileName, const wxString& format = wxT(""), long tsOffset = 0);
@@ -39,23 +45,23 @@ public:
 	void SetInterlaced(bool value);
 	/** Sets first field flag (Auto, TFF, BFF) */
 	void SetFirstField(FirstField firstField);
-	/** Sets start time */
+	/** Sets start time (in sec) */
 	void SetStartTime(double startTime);
-	/** Sets recording time */
+	/** Sets recording time (in sec) */
 	void SetRecordingTime(double recordingTime);
 	/** Sets video filters */
 	void SetVideoFilters(const wxString& videoFilters) { m_videoFilters = videoFilters; }
 	/** Sets audio filters */
 	void SetAudioFilters(int streamIndex, const wxString& audioFilters) { m_audioFilters[streamIndex] = audioFilters; }
+	/** Set filter to concat video segments (with reencoding) */
+	void ConcatVideo(const wxString& resultFile, int videoBitrate = 6000, bool copyAudio = true, bool copySubtitle = false);
+	/** Set filter and output to calculate replay gain values */
+	void ReplayGain(int audioStreamIdx);
 	
-	/** Starts transcoding. */
-	bool Run(bool& canceled);
-	/** Ends ttanscoding and closes all fiies. */
-	void End();
+	/** Returns transcoding command */
+	wxString GetCmd() const;
 	
-	const wxString& GetCmd() const { return m_cmd; }
 private:
-	unsigned int m_threadCount;
 	unsigned int m_inputFileCount;
 	wxString m_cmd;
 	wxString m_outputFormat;
